from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSDArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSDArchives.proto',
  package='TSD',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x11TSDArchives.proto\x12\x03TSD\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x11TSSArchives.proto\"M\n\x11\x45\x64geInsetsArchive\x12\x0b\n\x03top\x18\x01 \x02(\x02\x12\x0c\n\x04left\x18\x02 \x02(\x02\x12\x0e\n\x06\x62ottom\x18\x03 \x02(\x02\x12\r\n\x05right\x18\x04 \x02(\x02\"f\n\x0fGeometryArchive\x12\x1c\n\x08position\x18\x01 \x01(\x0b\x32\n.TSP.Point\x12\x17\n\x04size\x18\x02 \x01(\x0b\x32\t.TSP.Size\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\r\n\x05\x61ngle\x18\x04 \x01(\x02\"\x8e\x02\n\x16PointPathSourceArchive\x12=\n\x04type\x18\x01 \x01(\x0e\x32/.TSD.PointPathSourceArchive.PointPathSourceType\x12\x19\n\x05point\x18\x02 \x01(\x0b\x32\n.TSP.Point\x12\x1e\n\x0bnaturalSize\x18\x03 \x01(\x0b\x32\t.TSP.Size\"z\n\x13PointPathSourceType\x12\x17\n\x13kTSDLeftSingleArrow\x10\x00\x12\x18\n\x14kTSDRightSingleArrow\x10\x01\x12\x13\n\x0fkTSDDoubleArrow\x10\n\x12\x0c\n\x08kTSDStar\x10\x64\x12\r\n\x08kTSDPlus\x10\xc8\x01\"\x82\x02\n\x17ScalarPathSourceArchive\x12?\n\x04type\x18\x01 \x01(\x0e\x32\x31.TSD.ScalarPathSourceArchive.ScalarPathSourceType\x12\x0e\n\x06scalar\x18\x02 \x01(\x02\x12\x1e\n\x0bnaturalSize\x18\x03 \x01(\x0b\x32\t.TSP.Size\x12\x1b\n\x13is_curve_continuous\x18\x04 \x01(\x08\"Y\n\x14ScalarPathSourceType\x12\x18\n\x14kTSDRoundedRectangle\x10\x00\x12\x16\n\x12kTSDRegularPolygon\x10\x01\x12\x0f\n\x0bkTSDChevron\x10\x02\"k\n\x17\x42\x65zierPathSourceArchive\x12\x17\n\x0bpath_string\x18\x01 \x01(\tB\x02\x18\x01\x12\x1e\n\x0bnaturalSize\x18\x02 \x01(\x0b\x32\t.TSP.Size\x12\x17\n\x04path\x18\x03 \x01(\x0b\x32\t.TSP.Path\"\x9d\x01\n\x18\x43\x61lloutPathSourceArchive\x12\x1f\n\x0cnatural_size\x18\x01 \x01(\x0b\x32\t.TSP.Size\x12!\n\rtail_position\x18\x02 \x01(\x0b\x32\n.TSP.Point\x12\x11\n\ttail_size\x18\x03 \x01(\x02\x12\x15\n\rcorner_radius\x18\x04 \x01(\x02\x12\x13\n\x0b\x63\x65nter_tail\x18\x05 \x01(\x08\"\xb2\x02\n\x1f\x43onnectionLinePathSourceArchive\x12+\n\x05super\x18\x01 \x02(\x0b\x32\x1c.TSD.BezierPathSourceArchive\x12O\n\x04type\x18\x02 \x01(\x0e\x32\x41.TSD.ConnectionLinePathSourceArchive.ConnectionLinePathSourceType\x12\x13\n\x0boutset_from\x18\x03 \x01(\x02\x12\x11\n\toutset_to\x18\x04 \x01(\x02\"i\n\x1c\x43onnectionLinePathSourceType\x12#\n\x1fkTSDConnectionLineTypeQuadratic\x10\x00\x12$\n kTSDConnectionLineTypeOrthogonal\x10\x01\"\xb3\x03\n\x1f\x45\x64itableBezierPathSourceArchive\x12>\n\x08subpaths\x18\x01 \x03(\x0b\x32,.TSD.EditableBezierPathSourceArchive.Subpath\x12\x1e\n\x0bnaturalSize\x18\x02 \x01(\x0b\x32\t.TSP.Size\x1a\xab\x01\n\x04Node\x12\"\n\x0einControlPoint\x18\x01 \x02(\x0b\x32\n.TSP.Point\x12\x1d\n\tnodePoint\x18\x02 \x02(\x0b\x32\n.TSP.Point\x12#\n\x0foutControlPoint\x18\x03 \x02(\x0b\x32\n.TSP.Point\x12;\n\x04type\x18\x04 \x02(\x0e\x32-.TSD.EditableBezierPathSourceArchive.NodeType\x1aS\n\x07Subpath\x12\x38\n\x05nodes\x18\x01 \x03(\x0b\x32).TSD.EditableBezierPathSourceArchive.Node\x12\x0e\n\x06\x63losed\x18\x02 \x02(\x08\"-\n\x08NodeType\x12\t\n\x05sharp\x10\x01\x12\n\n\x06\x62\x65zier\x10\x02\x12\n\n\x06smooth\x10\x03\"\xf1\x03\n\x11PathSourceArchive\x12\x16\n\x0ehorizontalFlip\x18\x01 \x01(\x08\x12\x14\n\x0cverticalFlip\x18\x02 \x01(\x08\x12\x36\n\x11point_path_source\x18\x03 \x01(\x0b\x32\x1b.TSD.PointPathSourceArchive\x12\x38\n\x12scalar_path_source\x18\x04 \x01(\x0b\x32\x1c.TSD.ScalarPathSourceArchive\x12\x38\n\x12\x62\x65zier_path_source\x18\x05 \x01(\x0b\x32\x1c.TSD.BezierPathSourceArchive\x12:\n\x13\x63\x61llout_path_source\x18\x06 \x01(\x0b\x32\x1d.TSD.CalloutPathSourceArchive\x12I\n\x1b\x63onnection_line_path_source\x18\x07 \x01(\x0b\x32$.TSD.ConnectionLinePathSourceArchive\x12I\n\x1b\x65\x64itable_bezier_path_source\x18\x08 \x01(\x0b\x32$.TSD.EditableBezierPathSourceArchive\x12\x17\n\x0flocalizationKey\x18\t \x01(\t\x12\x17\n\x0fuserDefinedName\x18\n \x01(\t\"-\n\x14\x41ngleGradientArchive\x12\x15\n\rgradientangle\x18\x02 \x01(\x02\"r\n\x18TransformGradientArchive\x12\x19\n\x05start\x18\x01 \x01(\x0b\x32\n.TSP.Point\x12\x17\n\x03\x65nd\x18\x02 \x01(\x0b\x32\n.TSP.Point\x12\"\n\x0f\x62\x61seNaturalSize\x18\x03 \x01(\x0b\x32\t.TSP.Size\"\x84\x03\n\x0fGradientArchive\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.TSD.GradientArchive.GradientType\x12\x30\n\x05stops\x18\x02 \x03(\x0b\x32!.TSD.GradientArchive.GradientStop\x12\x0f\n\x07opacity\x18\x03 \x01(\x02\x12\x18\n\x10\x61\x64vancedGradient\x18\x04 \x01(\x08\x12\x30\n\ranglegradient\x18\x05 \x01(\x0b\x32\x19.TSD.AngleGradientArchive\x12\x38\n\x11transformgradient\x18\x06 \x01(\x0b\x32\x1d.TSD.TransformGradientArchive\x1aO\n\x0cGradientStop\x12\x19\n\x05\x63olor\x18\x01 \x01(\x0b\x32\n.TSP.Color\x12\x10\n\x08\x66raction\x18\x02 \x01(\x02\x12\x12\n\ninflection\x18\x03 \x01(\x02\"&\n\x0cGradientType\x12\n\n\x06Linear\x10\x00\x12\n\n\x06Radial\x10\x01\"\xf1\x03\n\x10ImageFillArchive\x12%\n\timagedata\x18\x06 \x01(\x0b\x32\x12.TSP.DataReference\x12;\n\ttechnique\x18\x02 \x01(\x0e\x32(.TSD.ImageFillArchive.ImageFillTechnique\x12\x18\n\x04tint\x18\x03 \x01(\x0b\x32\n.TSP.Color\x12\x1b\n\x08\x66illsize\x18\x04 \x01(\x0b\x32\t.TSP.Size\x12\x31\n\x11originalimagedata\x18\x07 \x01(\x0b\x32\x12.TSP.DataReferenceB\x02\x18\x01\x12,\n$interpretsUntaggedImageDataAsGeneric\x18\x08 \x01(\x08\x12\"\n\x0ereferencecolor\x18\t \x01(\x0b\x32\n.TSP.Color\x12*\n\x12\x64\x61tabase_imagedata\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1a\x64\x61tabase_originalimagedata\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\"]\n\x12ImageFillTechnique\x12\x0f\n\x0bNaturalSize\x10\x00\x12\x0b\n\x07Stretch\x10\x01\x12\x08\n\x04Tile\x10\x02\x12\x0f\n\x0bScaleToFill\x10\x03\x12\x0e\n\nScaleToFit\x10\x04\"\x80\x01\n\x0b\x46illArchive\x12\x19\n\x05\x63olor\x18\x01 \x01(\x0b\x32\n.TSP.Color\x12&\n\x08gradient\x18\x02 \x01(\x0b\x32\x14.TSD.GradientArchive\x12$\n\x05image\x18\x03 \x01(\x0b\x32\x15.TSD.ImageFillArchive*\x08\x08\x64\x10\x80\x80\x80\x80\x02\"\xcf\x01\n\x14StrokePatternArchive\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.TSD.StrokePatternArchive.StrokePatternType\x12\r\n\x05phase\x18\x02 \x01(\x02\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x0f\n\x07pattern\x18\x04 \x03(\x02\"M\n\x11StrokePatternType\x12\x0e\n\nTSDPattern\x10\x00\x12\x13\n\x0fTSDSolidPattern\x10\x01\x12\x13\n\x0fTSDEmptyPattern\x10\x02\"\xfd\x02\n\rStrokeArchive\x12\x19\n\x05\x63olor\x18\x01 \x01(\x0b\x32\n.TSP.Color\x12\r\n\x05width\x18\x02 \x01(\x02\x12\'\n\x03\x63\x61p\x18\x03 \x01(\x0e\x32\x1a.TSD.StrokeArchive.LineCap\x12\x1b\n\x04join\x18\x04 \x01(\x0e\x32\r.TSD.LineJoin\x12\x13\n\x0bmiter_limit\x18\x05 \x01(\x02\x12*\n\x07pattern\x18\x06 \x01(\x0b\x32\x19.TSD.StrokePatternArchive\x12-\n\x0csmart_stroke\x18\x07 \x01(\x0b\x32\x17.TSD.SmartStrokeArchive\x12 \n\x05\x66rame\x18\x08 \x01(\x0b\x32\x11.TSD.FrameArchive\x12\x35\n\x10patterned_stroke\x18\t \x01(\x0b\x32\x1b.TSD.PatternedStrokeArchive\"3\n\x07LineCap\x12\x0b\n\x07\x42uttCap\x10\x00\x12\x0c\n\x08RoundCap\x10\x01\x12\r\n\tSquareCap\x10\x02\"\x92\x01\n\x12SmartStrokeArchive\x12\x13\n\x0bstroke_name\x18\x02 \x01(\t\x12\x13\n\x0brandom_seed\x18\x03 \x01(\r\x12\x31\n\x0fparameterValues\x18\x04 \x01(\x0b\x32\x18.TSP.ReferenceDictionary\x12\x1f\n\x17pattern_offset_distance\x18\x05 \x01(\x01\"5\n\x0c\x46rameArchive\x12\x11\n\tframeName\x18\x02 \x01(\t\x12\x12\n\nassetScale\x18\x03 \x01(\x02\".\n\x16PatternedStrokeArchive\x12\x14\n\x0cpattern_name\x18\x02 \x01(\t\"\x91\x01\n\x0eLineEndArchive\x12\x17\n\x04path\x18\x01 \x01(\x0b\x32\t.TSP.Path\x12 \n\tline_join\x18\x02 \x01(\x0e\x32\r.TSD.LineJoin\x12\x1d\n\tend_point\x18\x03 \x01(\x0b\x32\n.TSP.Point\x12\x11\n\tis_filled\x18\x04 \x01(\x08\x12\x12\n\nidentifier\x18\x05 \x01(\t\"\x99\x03\n\rShadowArchive\x12\x19\n\x05\x63olor\x18\x01 \x01(\x0b\x32\n.TSP.Color\x12\x12\n\x05\x61ngle\x18\x02 \x01(\x02:\x03\x33\x31\x35\x12\x11\n\x06offset\x18\x03 \x01(\x02:\x01\x35\x12\x11\n\x06radius\x18\x04 \x01(\x05:\x01\x31\x12\x12\n\x07opacity\x18\x05 \x01(\x02:\x01\x31\x12\x18\n\nis_enabled\x18\x06 \x01(\x08:\x04true\x12+\n\x04type\x18\x07 \x01(\x0e\x32\x1d.TSD.ShadowArchive.ShadowType\x12*\n\ndropShadow\x18\x08 \x01(\x0b\x32\x16.TSD.DropShadowArchive\x12\x30\n\rcontactShadow\x18\t \x01(\x0b\x32\x19.TSD.ContactShadowArchive\x12.\n\x0c\x63urvedShadow\x18\n \x01(\x0b\x32\x18.TSD.CurvedShadowArchive\"J\n\nShadowType\x12\x11\n\rTSDDropShadow\x10\x00\x12\x14\n\x10TSDContactShadow\x10\x01\x12\x13\n\x0fTSDCurvedShadow\x10\x02\"\x13\n\x11\x44ropShadowArchive\";\n\x14\x43ontactShadowArchive\x12\x13\n\x06height\x18\x02 \x01(\x02:\x03\x30.2\x12\x0e\n\x06offset\x18\x04 \x01(\x02\")\n\x13\x43urvedShadowArchive\x12\x12\n\x05\x63urve\x18\x01 \x01(\x02:\x03\x30.6\")\n\x11ReflectionArchive\x12\x14\n\x07opacity\x18\x01 \x01(\x02:\x03\x30.5\"\xae\x02\n\x17ImageAdjustmentsArchive\x12\x10\n\x08\x65xposure\x18\x01 \x01(\x02\x12\x12\n\nsaturation\x18\x02 \x01(\x02\x12\x10\n\x08\x63ontrast\x18\x03 \x01(\x02\x12\x12\n\nhighlights\x18\x04 \x01(\x02\x12\x0f\n\x07shadows\x18\x05 \x01(\x02\x12\x11\n\tsharpness\x18\x06 \x01(\x02\x12\x0f\n\x07\x64\x65noise\x18\x07 \x01(\x02\x12\x13\n\x0btemperature\x18\x08 \x01(\x02\x12\x0c\n\x04tint\x18\t \x01(\x02\x12\x14\n\x0c\x62ottom_level\x18\n \x01(\x02\x12\x14\n\ttop_level\x18\x0b \x01(\x02:\x01\x31\x12\r\n\x05gamma\x18\x0c \x01(\x02\x12\x0f\n\x07\x65nhance\x18\r \x01(\x08\x12#\n\x1brepresents_sage_adjustments\x18\x0e \x01(\x08\"\x9a\x02\n\x1bShapeStylePropertiesArchive\x12\x1e\n\x04\x66ill\x18\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12\"\n\x06stroke\x18\x02 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x0f\n\x07opacity\x18\x03 \x01(\x02\x12\"\n\x06shadow\x18\x04 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12*\n\nreflection\x18\x05 \x01(\x0b\x32\x16.TSD.ReflectionArchive\x12*\n\rhead_line_end\x18\x06 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12*\n\rtail_line_end\x18\x07 \x01(\x0b\x32\x13.TSD.LineEndArchive\"\x89\x01\n\x11ShapeStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12:\n\x10shape_properties\x18\x0b \x01(\x0b\x32 .TSD.ShapeStylePropertiesArchive\"\xa2\x01\n\x1bMediaStylePropertiesArchive\x12\"\n\x06stroke\x18\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x0f\n\x07opacity\x18\x02 \x01(\x02\x12\"\n\x06shadow\x18\x03 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12*\n\nreflection\x18\x04 \x01(\x0b\x32\x16.TSD.ReflectionArchive\"\x89\x01\n\x11MediaStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12:\n\x10media_properties\x18\x0b \x01(\x0b\x32 .TSD.MediaStylePropertiesArchive\"\xf6\x03\n\x13ThemePresetsArchive\x12/\n\x15gradient_fill_presets\x18\x01 \x03(\x0b\x32\x10.TSD.FillArchive\x12,\n\x12image_fill_presets\x18\x02 \x03(\x0b\x32\x10.TSD.FillArchive\x12*\n\x0eshadow_presets\x18\x03 \x03(\x0b\x32\x12.TSD.ShadowArchive\x12*\n\x12line_style_presets\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\x13shape_style_presets\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x15textbox_style_presets\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\x13image_style_presets\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\x13movie_style_presets\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1a\x64rawing_line_style_presets\x18\t \x03(\x0b\x32\x0e.TSP.Reference2>\n\textension\x12\x11.TSS.ThemeArchive\x18\x64 \x01(\x0b\x32\x18.TSD.ThemePresetsArchive\"\xbc\x01\n$ThemeReplaceFillPresetCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05theme\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x04\x66ill\x18\x03 \x02(\x0b\x32\x10.TSD.FillArchive\x12\"\n\x08old_fill\x18\x04 \x02(\x0b\x32\x10.TSD.FillArchive\x12\r\n\x05index\x18\x05 \x02(\r\"\xb5\x03\n\x0f\x44rawableArchive\x12&\n\x08geometry\x18\x01 \x01(\x0b\x32\x14.TSD.GeometryArchive\x12\x1e\n\x06parent\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x38\n\x12\x65xterior_text_wrap\x18\x03 \x01(\x0b\x32\x1c.TSD.ExteriorTextWrapArchive\x12\x15\n\rhyperlink_url\x18\x04 \x01(\t\x12\x0e\n\x06locked\x18\x05 \x01(\x08\x12\x1f\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1b\n\x13\x61spect_ratio_locked\x18\x07 \x01(\x08\x12!\n\x19\x61\x63\x63\x65ssibility_description\x18\x08 \x01(\t\x12*\n\x12pencil_annotations\x18\t \x03(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05title\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x07\x63\x61ption\x18\x0b \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0ctitle_hidden\x18\x0c \x01(\x08\x12\x16\n\x0e\x63\x61ption_hidden\x18\r \x01(\x08\"|\n\x10\x43ontainerArchive\x12&\n\x08geometry\x18\x01 \x01(\x0b\x32\x14.TSD.GeometryArchive\x12\x1e\n\x06parent\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\x08\x63hildren\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\"\x93\x01\n\x0cGroupArchive\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSD.DrawableArchive\x12 \n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1a\x66\x61ke_shape_for_empty_group\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference*\x08\x08\x64\x10\x80\x80\x80\x80\x02\"H\n\x1f\x46reehandDrawingAnimationArchive\x12\x10\n\x08\x64uration\x18\x01 \x01(\x01\x12\x13\n\x0bshould_loop\x18\x02 \x01(\x08\"\xda\x01\n\x16\x46reehandDrawingArchive\x12$\n\x0cspacer_shape\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x0f\n\x07opacity\x18\x02 \x01(\x01\x12\x37\n\tanimation\x18\x03 \x01(\x0b\x32$.TSD.FreehandDrawingAnimationArchive2P\n\x18\x66reehand_drawing_archive\x12\x11.TSD.GroupArchive\x18\x64 \x01(\x0b\x32\x1b.TSD.FreehandDrawingArchive\"\x83\x02\n\x0cShapeArchive\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSD.DrawableArchive\x12\x1d\n\x05style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12*\n\npathsource\x18\x03 \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12.\n\rhead_line_end\x18\x04 \x01(\x0b\x32\x13.TSD.LineEndArchiveB\x02\x18\x01\x12.\n\rtail_line_end\x18\x05 \x01(\x0b\x32\x13.TSD.LineEndArchiveB\x02\x18\x01\x12#\n\x1bstrokePatternOffsetDistance\x18\x06 \x01(\x02\"\xd5\x01\n\x15\x43onnectionLineArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSD.ShapeArchive\x12&\n\x0e\x63onnected_from\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12$\n\x0c\x63onnected_to\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12$\n\x11\x63onnected_to_uuid\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12&\n\x13\x63onnected_from_uuid\x18\x05 \x01(\x0b\x32\t.TSP.UUID\"\xce\x06\n\x0cImageArchive\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSD.DrawableArchive\x12 \n\x04\x64\x61ta\x18\x0b \x01(\x0b\x32\x12.TSP.DataReference\x12\x1d\n\x05style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x0coriginalSize\x18\x04 \x01(\x0b\x32\t.TSP.Size\x12\x1c\n\x04mask\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\rthumbnailData\x18\x0c \x01(\x0b\x32\x12.TSP.DataReference\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12(\n\x0coriginalData\x18\r \x01(\x0b\x32\x12.TSP.DataReference\x12\x1e\n\x0bnaturalSize\x18\t \x01(\x0b\x32\t.TSP.Size\x12#\n\x10instantAlphaPath\x18\n \x01(\x0b\x32\t.TSP.Path\x12\x36\n\x10imageAdjustments\x18\x0e \x01(\x0b\x32\x1c.TSD.ImageAdjustmentsArchive\x12-\n\x11\x65nhancedImageData\x18\x11 \x01(\x0b\x32\x12.TSP.DataReference\x12-\n\x11\x61\x64justedImageData\x18\x0f \x01(\x0b\x32\x12.TSP.DataReference\x12\x36\n\x1athumbnailAdjustedImageData\x18\x10 \x01(\x0b\x32\x12.TSP.DataReference\x12,\n$interpretsUntaggedImageDataAsGeneric\x18\x12 \x01(\x08\x12%\n\rdatabase_data\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x64\x61tabase_thumbnailData\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12-\n\x15\x64\x61tabase_originalData\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x0btraced_path\x18\x13 \x01(\x0b\x32\t.TSP.Path\x12%\n\x0b\x61ttribution\x18\x14 \x01(\x0b\x32\x10.TSD.Attribution\x12 \n\x18should_trace_pdf_content\x18\x15 \x01(\x08*\x05\x08\x64\x10\xe8\x07\"^\n\x0bMaskArchive\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSD.DrawableArchive\x12*\n\npathsource\x18\x02 \x01(\x0b\x32\x16.TSD.PathSourceArchive\"\xcf\x01\n\x13ImageDataAttributes\x12\x1d\n\npixel_size\x18\x01 \x01(\x0b\x32\t.TSP.Size\x12\x15\n\rimage_is_srgb\x18\x02 \x01(\x08\x12\x34\n,should_be_interpreted_as_generic_if_untagged\x18\x03 \x01(\x08\x32L\n\x15image_data_attributes\x12\x13.TSP.DataAttributes\x18\x64 \x01(\x0b\x32\x18.TSD.ImageDataAttributes\"\xb0\x08\n\x0cMovieArchive\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSD.DrawableArchive\x12%\n\tmovieData\x18\x0e \x01(\x0b\x32\x12.TSP.DataReference\x12\x36\n\x1aimportedAuxiliaryMovieData\x18\x16 \x01(\x0b\x32\x12.TSP.DataReference\x12\x37\n/imported_auxiliary_movie_data_original_filename\x18\x19 \x01(\t\x12\x16\n\x0emovieRemoteURL\x18\x11 \x01(\t\x12\x11\n\tstartTime\x18\x03 \x01(\x02\x12\x0f\n\x07\x65ndTime\x18\x04 \x01(\x02\x12\x12\n\nposterTime\x18\x05 \x01(\x02\x12\x1f\n\x13loopOptionAsInteger\x18\x06 \x01(\rB\x02\x18\x01\x12\x36\n\x0bloop_option\x18\x18 \x01(\x0e\x32!.TSD.MovieArchive.MovieLoopOption\x12\x0e\n\x06volume\x18\x07 \x01(\x02\x12\x14\n\x08\x61utoPlay\x18\x08 \x01(\x08\x42\x02\x18\x01\x12\x11\n\taudioOnly\x18\t \x01(\x08\x12\x11\n\tstreaming\x18\x12 \x01(\x08\x12\x1c\n\x14nativeAudioRecording\x18\x1b \x01(\x08\x12\x19\n\x11playsAcrossSlides\x18\x1c \x01(\x08\x12+\n\x0fposterImageData\x18\x0f \x01(\x0b\x32\x12.TSP.DataReference\x12.\n\x12\x61udioOnlyImageData\x18\x10 \x01(\x0b\x32\x12.TSP.DataReference\x12\x31\n)poster_image_generated_with_alpha_support\x18\x17 \x01(\x08\x12\x15\n\rplayableState\x18\x0c \x01(\r\x12\r\n\x05\x66lags\x18\r \x01(\r\x12*\n\x12\x64\x61tabase_movieData\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18\x64\x61tabase_posterImageData\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x64\x61tabase_audioOnlyImageData\x18\x0b \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05style\x18\x13 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x0coriginalSize\x18\x14 \x01(\x0b\x32\t.TSP.Size\x12\x1e\n\x0bnaturalSize\x18\x15 \x01(\x0b\x32\t.TSP.Size\x12%\n\x0b\x61ttribution\x18\x1a \x01(\x0b\x32\x10.TSD.Attribution\x12*\n\x0b\x66ingerprint\x18\x1d \x01(\x0b\x32\x15.TSD.MovieFingerprint\"9\n\x0fMovieLoopOption\x12\x08\n\x04None\x10\x00\x12\n\n\x06Repeat\x10\x01\x12\x10\n\x0c\x42\x61\x63kAndForth\x10\x02\"\x8b\x01\n\x17\x45xteriorTextWrapArchive\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x11\n\tdirection\x18\x02 \x01(\r\x12\x10\n\x08\x66it_type\x18\x03 \x01(\r\x12\x0e\n\x06margin\x18\x04 \x01(\x02\x12\x17\n\x0f\x61lpha_threshold\x18\x05 \x01(\x02\x12\x14\n\x0cis_html_wrap\x18\x06 \x01(\x08\"\x8c\x01\n\x1a\x44rawableContentDescription\x12\x14\n\x0c\x65lement_kind\x18\x01 \x01(\r\x12\x1b\n\x13is_anchored_to_text\x18\x02 \x01(\x08\x12\x1e\n\x16is_floating_above_text\x18\x03 \x01(\x08\x12\x1b\n\x13is_inline_with_text\x18\x04 \x01(\x08\"{\n!FreehandDrawingContentDescription\x12.\n\x05super\x18\x01 \x02(\x0b\x32\x1f.TSD.DrawableContentDescription\x12&\n\x1esource_doc_wanted_spacer_shape\x18\x02 \x01(\x08\"\xa6\x05\n\x1d\x46reehandDrawingToolkitUIState\x12%\n\rcurrent_color\x18\x01 \x01(\x0b\x32\n.TSP.ColorB\x02\x18\x01\x12]\n\x19most_recent_pen_tool_type\x18\x02 \x01(\x0e\x32:.TSD.FreehandDrawingToolkitUIState.FreehandDrawingToolType\x12\x18\n\x10pen_tool_opacity\x18\x03 \x01(\x02\x12\x1f\n\x17pen_tool_unscaled_width\x18\x04 \x01(\x02\x12\x1b\n\x13pencil_tool_opacity\x18\x05 \x01(\x02\x12\"\n\x1apencil_tool_unscaled_width\x18\x06 \x01(\x02\x12\x1b\n\x13\x63rayon_tool_opacity\x18\x07 \x01(\x02\x12\"\n\x1a\x63rayon_tool_unscaled_width\x18\x08 \x01(\x02\x12\x19\n\x11\x66ill_tool_opacity\x18\t \x01(\x02\x12 \n\x18\x65raser_tool_scaled_width\x18\n \x01(\x02\x12(\n eraser_tool_erases_whole_objects\x18\x0b \x01(\x08\x12\"\n\x0epen_tool_color\x18\x0c \x01(\x0b\x32\n.TSP.Color\x12%\n\x11pencil_tool_color\x18\r \x01(\x0b\x32\n.TSP.Color\x12%\n\x11\x63rayon_tool_color\x18\x0e \x01(\x0b\x32\n.TSP.Color\x12#\n\x0f\x66ill_tool_color\x18\x0f \x01(\x0b\x32\n.TSP.Color\"D\n\x17\x46reehandDrawingToolType\x12\x07\n\x03Pen\x10\x00\x12\n\n\x06Pencil\x10\x01\x12\n\n\x06\x43rayon\x10\x02\x12\x08\n\x04\x46ill\x10\x03\"\x17\n\x15StandinCaptionArchive\"\xb3\x01\n\x0cGuideArchive\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.TSD.GuideArchive.GuideType\x12\x0e\n\x06offset\x18\x02 \x01(\x02\x12\r\n\x05start\x18\x03 \x01(\x02\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x02\x12\x0f\n\x07\x64ynamic\x18\x05 \x01(\x08\x12\x10\n\x08infinite\x18\x06 \x01(\x08\")\n\tGuideType\x12\x0e\n\nHorizontal\x10\x00\x12\x0c\n\x08Vertical\x10\x01\"\x8c\x01\n\x17UserDefinedGuideArchive\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.TSD.UserDefinedGuideArchive.GuideType\x12\x10\n\x08position\x18\x02 \x01(\x02\")\n\tGuideType\x12\x0e\n\nHorizontal\x10\x00\x12\x0c\n\x08Vertical\x10\x01\"N\n\x13GuideStorageArchive\x12\x37\n\x11userDefinedGuides\x18\x01 \x03(\x0b\x32\x1c.TSD.UserDefinedGuideArchive\"\x8d\x01\n\x16\x43\x61nvasSelectionArchive\x12\x1d\n\x05infos\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x15non_interactive_infos\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12%\n\tcontainer\x18\x02 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\"h\n\x18\x44rawableSelectionArchive\x12\x1d\n\x05infos\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x15non_interactive_infos\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\"x\n\x15GroupSelectionArchive\x12,\n\x05super\x18\x01 \x02(\x0b\x32\x1d.TSD.DrawableSelectionArchive\x12\x31\n)has_selected_infos_in_non_group_container\x18\x02 \x01(\x08\"\x16\n\x14PathSelectionArchive\"\x1f\n\x1dInfoHyperlinkSelectionArchive\"\x88\x01\n\x15\x43ommentStorageArchive\x12\x0c\n\x04text\x18\x01 \x01(\t\x12 \n\rcreation_date\x18\x02 \x01(\x0b\x32\t.TSP.Date\x12\x1e\n\x06\x61uthor\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x07replies\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\"\xa9\x01\n%ReplaceAnnotationAuthorCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12-\n\x15old_annotation_author\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12-\n\x15new_annotation_author\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"L\n\x17PencilAnnotationArchive\x12\x31\n\x19pencil_annotation_storage\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"M\n PencilAnnotationSelectionArchive\x12)\n\x11pencil_annotation\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"\xc6\x07\n\x1ePencilAnnotationStorageArchive\x12\x19\n\x11\x61ttached_location\x18\x01 \x01(\x05\x12!\n\rmarkup_offset\x18\x02 \x01(\x0b\x32\n.TSP.Point\x12,\n\x10rasterized_image\x18\x03 \x01(\x0b\x32\x12.TSP.DataReference\x12\x32\n\x16legacy_encoded_drawing\x18\x04 \x01(\x0b\x32\x12.TSP.DataReference\x12\x1f\n\x0c\x64rawing_path\x18\x05 \x01(\x0b\x32\t.TSP.Path\x12/\n\x1bstrokes_bounding_box_origin\x18\x06 \x01(\x0b\x32\n.TSP.Point\x12,\n\x19strokes_bounding_box_size\x18\x07 \x01(\x0b\x32\t.TSP.Size\x12\x15\n\rattached_type\x18\x08 \x01(\x05\x12)\n\x16original_attached_size\x18\t \x01(\x0b\x32\t.TSP.Size\x12-\n%percent_of_pa_contained_in_parent_rep\x18\n \x01(\x01\x12$\n\x1ctext_baselines_touched_count\x18\x0b \x01(\x04\x12\x1d\n\x15visible_strokes_count\x18\x0c \x01(\x04\x12\x1d\n\tpen_color\x18\r \x01(\x0b\x32\n.TSP.Color\x12\x11\n\ttool_type\x18\x0e \x01(\x05\x12,\n\x14\x63\x61llout_sub_storages\x18\x0f \x03(\x0b\x32\x0e.TSP.Reference\x12 \n\rcreation_date\x18\x10 \x01(\x0b\x32\t.TSP.Date\x12\'\n\x1fpencil_annotation_drawing_scale\x18\x11 \x01(\x01\x12 \n\x18\x63ompound_annotation_type\x18\x12 \x01(\x05\x12$\n\x0csub_storages\x18\x13 \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\x0f\x65ncoded_drawing\x18\x14 \x01(\x0b\x32\x12.TSP.DataReference\x12.\n\x1astroke_points_frame_origin\x18\x15 \x01(\x0b\x32\n.TSP.Point\x12+\n\x18stroke_points_frame_size\x18\x16 \x01(\x0b\x32\t.TSP.Size\x12)\n\x15rendered_frame_origin\x18\x17 \x01(\x0b\x32\n.TSP.Point\x12&\n\x13rendered_frame_size\x18\x18 \x01(\x0b\x32\t.TSP.Size\"9\n\x1cSpecColorFillSetColorArchive\x12\x19\n\x05\x63olor\x18\x01 \x02(\x0b\x32\n.TSP.Color\"4\n\x1dSpecFrameSetAssetScaleArchive\x12\x13\n\x0b\x61sset_scale\x18\x01 \x02(\x01\"0\n\x1fSpecGradientFillSetAngleArchive\x12\r\n\x05\x61ngle\x18\x01 \x02(\x01\"5\n SpecImageFillSetTechniqueArchive\x12\x11\n\ttechnique\x18\x01 \x02(\x05\"2\n\x1fSpecReflectionSetOpacityArchive\x12\x0f\n\x07opacity\x18\x01 \x02(\x01\"*\n\x19SpecShadowSetAngleArchive\x12\r\n\x05\x61ngle\x18\x01 \x02(\x01\"6\n\x19SpecShadowSetColorArchive\x12\x19\n\x05\x63olor\x18\x01 \x02(\x0b\x32\n.TSP.Color\",\n\x1aSpecShadowSetOffsetArchive\x12\x0e\n\x06offset\x18\x01 \x02(\x01\".\n\x1bSpecShadowSetOpacityArchive\x12\x0f\n\x07opacity\x18\x01 \x02(\x01\",\n\x1aSpecShadowSetRadiusArchive\x12\x0e\n\x06radius\x18\x01 \x02(\x05\"6\n\x19SpecStrokeSetColorArchive\x12\x19\n\x05\x63olor\x18\x01 \x02(\x0b\x32\n.TSP.Color\"\xad\x01\n\x1bSpecStrokeSetPatternArchive\x12\x10\n\x08line_cap\x18\x01 \x01(\x05\x12\x11\n\tline_join\x18\x02 \x01(\x05\x12\x13\n\x0bmiter_limit\x18\x03 \x01(\x01\x12\r\n\x05width\x18\x04 \x01(\x01\x12\x19\n\x05\x63olor\x18\x05 \x01(\x0b\x32\n.TSP.Color\x12*\n\x07pattern\x18\x06 \x02(\x0b\x32\x19.TSD.StrokePatternArchive\"*\n\x19SpecStrokeSetWidthArchive\x12\r\n\x05width\x18\x01 \x02(\x01\"u\n\x0b\x41ttribution\x12\r\n\x05title\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65scription_text\x18\x02 \x01(\t\x12\x14\n\x0c\x65xternal_url\x18\x03 \x01(\t\x12\x13\n\x0b\x61uthor_name\x18\x04 \x01(\t\x12\x12\n\nauthor_url\x18\x05 \x01(\t\"O\n\x10MovieFingerprint\x12*\n\x06tracks\x18\x01 \x03(\x0b\x32\x1a.TSD.MovieFingerprintTrack\x12\x0f\n\x07version\x18\x02 \x03(\r\"\x85\x05\n\x15MovieFingerprintTrack\x12\x12\n\nmedia_type\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12 \n\x18total_sample_data_length\x18\x03 \x01(\x03\x12!\n\x19sample_data_digest_string\x18\x04 \x01(\t\x12\x1e\n\x16time_range_start_value\x18\x05 \x01(\x03\x12\"\n\x1atime_range_start_timescale\x18\x06 \x01(\x05\x12!\n\x19time_range_start_is_valid\x18\x07 \x01(\x08\x12!\n\x19time_range_duration_value\x18\x08 \x01(\x03\x12%\n\x1dtime_range_duration_timescale\x18\t \x01(\x05\x12$\n\x1ctime_range_duration_is_valid\x18\n \x01(\x08\x12\x1f\n\x0cnatural_size\x18\x0b \x01(\x0b\x32\t.TSP.Size\x12\x1d\n\x15preferred_transform_a\x18\x0c \x01(\x01\x12\x1d\n\x15preferred_transform_b\x18\r \x01(\x01\x12\x1d\n\x15preferred_transform_c\x18\x0e \x01(\x01\x12\x1d\n\x15preferred_transform_d\x18\x0f \x01(\x01\x12\x1e\n\x16preferred_transform_tx\x18\x10 \x01(\x01\x12\x1e\n\x16preferred_transform_ty\x18\x11 \x01(\x01\x12\x18\n\x10preferred_volume\x18\x12 \x01(\x01\x12\x15\n\rlanguage_code\x18\x13 \x01(\t\x12\x1d\n\x15\x65xtended_language_tag\x18\x14 \x01(\t*7\n\x08LineJoin\x12\r\n\tMiterJoin\x10\x00\x12\r\n\tRoundJoin\x10\x01\x12\r\n\tBevelJoin\x10\x02:A\n\x04\x66ill\x12 .TSS.CommandPropertyEntryArchive\x18\xc8\x01 \x01(\x0b\x32\x10.TSD.FillArchive:E\n\x06stroke\x12 .TSS.CommandPropertyEntryArchive\x18\xc9\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,])

_LINEJOIN = _descriptor.EnumDescriptor(
  name='LineJoin',
  full_name='TSD.LineJoin',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MiterJoin', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RoundJoin', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BevelJoin', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15546,
  serialized_end=15601,
)
_sym_db.RegisterEnumDescriptor(_LINEJOIN)

LineJoin = enum_type_wrapper.EnumTypeWrapper(_LINEJOIN)
MiterJoin = 0
RoundJoin = 1
BevelJoin = 2

FILL_FIELD_NUMBER = 200
fill = _descriptor.FieldDescriptor(
  name='fill', full_name='TSD.fill', index=0,
  number=200, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
STROKE_FIELD_NUMBER = 201
stroke = _descriptor.FieldDescriptor(
  name='stroke', full_name='TSD.stroke', index=1,
  number=201, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)

_POINTPATHSOURCEARCHIVE_POINTPATHSOURCETYPE = _descriptor.EnumDescriptor(
  name='PointPathSourceType',
  full_name='TSD.PointPathSourceArchive.PointPathSourceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kTSDLeftSingleArrow', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSDRightSingleArrow', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSDDoubleArrow', index=2, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSDStar', index=3, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSDPlus', index=4, number=200,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=415,
  serialized_end=537,
)
_sym_db.RegisterEnumDescriptor(_POINTPATHSOURCEARCHIVE_POINTPATHSOURCETYPE)

_SCALARPATHSOURCEARCHIVE_SCALARPATHSOURCETYPE = _descriptor.EnumDescriptor(
  name='ScalarPathSourceType',
  full_name='TSD.ScalarPathSourceArchive.ScalarPathSourceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kTSDRoundedRectangle', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSDRegularPolygon', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSDChevron', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=709,
  serialized_end=798,
)
_sym_db.RegisterEnumDescriptor(_SCALARPATHSOURCEARCHIVE_SCALARPATHSOURCETYPE)

_CONNECTIONLINEPATHSOURCEARCHIVE_CONNECTIONLINEPATHSOURCETYPE = _descriptor.EnumDescriptor(
  name='ConnectionLinePathSourceType',
  full_name='TSD.ConnectionLinePathSourceArchive.ConnectionLinePathSourceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kTSDConnectionLineTypeQuadratic', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSDConnectionLineTypeOrthogonal', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1271,
  serialized_end=1376,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONLINEPATHSOURCEARCHIVE_CONNECTIONLINEPATHSOURCETYPE)

_EDITABLEBEZIERPATHSOURCEARCHIVE_NODETYPE = _descriptor.EnumDescriptor(
  name='NodeType',
  full_name='TSD.EditableBezierPathSourceArchive.NodeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='sharp', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='bezier', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='smooth', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1769,
  serialized_end=1814,
)
_sym_db.RegisterEnumDescriptor(_EDITABLEBEZIERPATHSOURCEARCHIVE_NODETYPE)

_GRADIENTARCHIVE_GRADIENTTYPE = _descriptor.EnumDescriptor(
  name='GradientType',
  full_name='TSD.GradientArchive.GradientType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Linear', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Radial', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2830,
  serialized_end=2868,
)
_sym_db.RegisterEnumDescriptor(_GRADIENTARCHIVE_GRADIENTTYPE)

_IMAGEFILLARCHIVE_IMAGEFILLTECHNIQUE = _descriptor.EnumDescriptor(
  name='ImageFillTechnique',
  full_name='TSD.ImageFillArchive.ImageFillTechnique',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NaturalSize', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Stretch', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Tile', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ScaleToFill', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ScaleToFit', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3275,
  serialized_end=3368,
)
_sym_db.RegisterEnumDescriptor(_IMAGEFILLARCHIVE_IMAGEFILLTECHNIQUE)

_STROKEPATTERNARCHIVE_STROKEPATTERNTYPE = _descriptor.EnumDescriptor(
  name='StrokePatternType',
  full_name='TSD.StrokePatternArchive.StrokePatternType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TSDPattern', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSDSolidPattern', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSDEmptyPattern', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3632,
  serialized_end=3709,
)
_sym_db.RegisterEnumDescriptor(_STROKEPATTERNARCHIVE_STROKEPATTERNTYPE)

_STROKEARCHIVE_LINECAP = _descriptor.EnumDescriptor(
  name='LineCap',
  full_name='TSD.StrokeArchive.LineCap',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ButtCap', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RoundCap', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SquareCap', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4042,
  serialized_end=4093,
)
_sym_db.RegisterEnumDescriptor(_STROKEARCHIVE_LINECAP)

_SHADOWARCHIVE_SHADOWTYPE = _descriptor.EnumDescriptor(
  name='ShadowType',
  full_name='TSD.ShadowArchive.ShadowType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TSDDropShadow', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSDContactShadow', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSDCurvedShadow', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4831,
  serialized_end=4905,
)
_sym_db.RegisterEnumDescriptor(_SHADOWARCHIVE_SHADOWTYPE)

_MOVIEARCHIVE_MOVIELOOPOPTION = _descriptor.EnumDescriptor(
  name='MovieLoopOption',
  full_name='TSD.MovieArchive.MovieLoopOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Repeat', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BackAndForth', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10466,
  serialized_end=10523,
)
_sym_db.RegisterEnumDescriptor(_MOVIEARCHIVE_MOVIELOOPOPTION)

_FREEHANDDRAWINGTOOLKITUISTATE_FREEHANDDRAWINGTOOLTYPE = _descriptor.EnumDescriptor(
  name='FreehandDrawingToolType',
  full_name='TSD.FreehandDrawingToolkitUIState.FreehandDrawingToolType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Pen', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Pencil', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Crayon', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Fill', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11546,
  serialized_end=11614,
)
_sym_db.RegisterEnumDescriptor(_FREEHANDDRAWINGTOOLKITUISTATE_FREEHANDDRAWINGTOOLTYPE)

_GUIDEARCHIVE_GUIDETYPE = _descriptor.EnumDescriptor(
  name='GuideType',
  full_name='TSD.GuideArchive.GuideType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Horizontal', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Vertical', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11780,
  serialized_end=11821,
)
_sym_db.RegisterEnumDescriptor(_GUIDEARCHIVE_GUIDETYPE)

_USERDEFINEDGUIDEARCHIVE_GUIDETYPE = _descriptor.EnumDescriptor(
  name='GuideType',
  full_name='TSD.UserDefinedGuideArchive.GuideType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Horizontal', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Vertical', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11780,
  serialized_end=11821,
)
_sym_db.RegisterEnumDescriptor(_USERDEFINEDGUIDEARCHIVE_GUIDETYPE)


_EDGEINSETSARCHIVE = _descriptor.Descriptor(
  name='EdgeInsetsArchive',
  full_name='TSD.EdgeInsetsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top', full_name='TSD.EdgeInsetsArchive.top', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left', full_name='TSD.EdgeInsetsArchive.left', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom', full_name='TSD.EdgeInsetsArchive.bottom', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right', full_name='TSD.EdgeInsetsArchive.right', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=160,
)


_GEOMETRYARCHIVE = _descriptor.Descriptor(
  name='GeometryArchive',
  full_name='TSD.GeometryArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='TSD.GeometryArchive.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='TSD.GeometryArchive.size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='TSD.GeometryArchive.flags', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle', full_name='TSD.GeometryArchive.angle', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=264,
)


_POINTPATHSOURCEARCHIVE = _descriptor.Descriptor(
  name='PointPathSourceArchive',
  full_name='TSD.PointPathSourceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.PointPathSourceArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='point', full_name='TSD.PointPathSourceArchive.point', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='naturalSize', full_name='TSD.PointPathSourceArchive.naturalSize', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _POINTPATHSOURCEARCHIVE_POINTPATHSOURCETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=537,
)


_SCALARPATHSOURCEARCHIVE = _descriptor.Descriptor(
  name='ScalarPathSourceArchive',
  full_name='TSD.ScalarPathSourceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.ScalarPathSourceArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scalar', full_name='TSD.ScalarPathSourceArchive.scalar', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='naturalSize', full_name='TSD.ScalarPathSourceArchive.naturalSize', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_curve_continuous', full_name='TSD.ScalarPathSourceArchive.is_curve_continuous', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCALARPATHSOURCEARCHIVE_SCALARPATHSOURCETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=798,
)


_BEZIERPATHSOURCEARCHIVE = _descriptor.Descriptor(
  name='BezierPathSourceArchive',
  full_name='TSD.BezierPathSourceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_string', full_name='TSD.BezierPathSourceArchive.path_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='naturalSize', full_name='TSD.BezierPathSourceArchive.naturalSize', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='TSD.BezierPathSourceArchive.path', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=907,
)


_CALLOUTPATHSOURCEARCHIVE = _descriptor.Descriptor(
  name='CalloutPathSourceArchive',
  full_name='TSD.CalloutPathSourceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='natural_size', full_name='TSD.CalloutPathSourceArchive.natural_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tail_position', full_name='TSD.CalloutPathSourceArchive.tail_position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tail_size', full_name='TSD.CalloutPathSourceArchive.tail_size', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='corner_radius', full_name='TSD.CalloutPathSourceArchive.corner_radius', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='center_tail', full_name='TSD.CalloutPathSourceArchive.center_tail', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=1067,
)


_CONNECTIONLINEPATHSOURCEARCHIVE = _descriptor.Descriptor(
  name='ConnectionLinePathSourceArchive',
  full_name='TSD.ConnectionLinePathSourceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ConnectionLinePathSourceArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.ConnectionLinePathSourceArchive.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outset_from', full_name='TSD.ConnectionLinePathSourceArchive.outset_from', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outset_to', full_name='TSD.ConnectionLinePathSourceArchive.outset_to', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTIONLINEPATHSOURCEARCHIVE_CONNECTIONLINEPATHSOURCETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1070,
  serialized_end=1376,
)


_EDITABLEBEZIERPATHSOURCEARCHIVE_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='TSD.EditableBezierPathSourceArchive.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inControlPoint', full_name='TSD.EditableBezierPathSourceArchive.Node.inControlPoint', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodePoint', full_name='TSD.EditableBezierPathSourceArchive.Node.nodePoint', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outControlPoint', full_name='TSD.EditableBezierPathSourceArchive.Node.outControlPoint', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.EditableBezierPathSourceArchive.Node.type', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1511,
  serialized_end=1682,
)

_EDITABLEBEZIERPATHSOURCEARCHIVE_SUBPATH = _descriptor.Descriptor(
  name='Subpath',
  full_name='TSD.EditableBezierPathSourceArchive.Subpath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='TSD.EditableBezierPathSourceArchive.Subpath.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closed', full_name='TSD.EditableBezierPathSourceArchive.Subpath.closed', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1684,
  serialized_end=1767,
)

_EDITABLEBEZIERPATHSOURCEARCHIVE = _descriptor.Descriptor(
  name='EditableBezierPathSourceArchive',
  full_name='TSD.EditableBezierPathSourceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subpaths', full_name='TSD.EditableBezierPathSourceArchive.subpaths', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='naturalSize', full_name='TSD.EditableBezierPathSourceArchive.naturalSize', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EDITABLEBEZIERPATHSOURCEARCHIVE_NODE, _EDITABLEBEZIERPATHSOURCEARCHIVE_SUBPATH, ],
  enum_types=[
    _EDITABLEBEZIERPATHSOURCEARCHIVE_NODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1379,
  serialized_end=1814,
)


_PATHSOURCEARCHIVE = _descriptor.Descriptor(
  name='PathSourceArchive',
  full_name='TSD.PathSourceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizontalFlip', full_name='TSD.PathSourceArchive.horizontalFlip', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verticalFlip', full_name='TSD.PathSourceArchive.verticalFlip', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='point_path_source', full_name='TSD.PathSourceArchive.point_path_source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scalar_path_source', full_name='TSD.PathSourceArchive.scalar_path_source', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bezier_path_source', full_name='TSD.PathSourceArchive.bezier_path_source', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callout_path_source', full_name='TSD.PathSourceArchive.callout_path_source', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connection_line_path_source', full_name='TSD.PathSourceArchive.connection_line_path_source', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='editable_bezier_path_source', full_name='TSD.PathSourceArchive.editable_bezier_path_source', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localizationKey', full_name='TSD.PathSourceArchive.localizationKey', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userDefinedName', full_name='TSD.PathSourceArchive.userDefinedName', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1817,
  serialized_end=2314,
)


_ANGLEGRADIENTARCHIVE = _descriptor.Descriptor(
  name='AngleGradientArchive',
  full_name='TSD.AngleGradientArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gradientangle', full_name='TSD.AngleGradientArchive.gradientangle', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2316,
  serialized_end=2361,
)


_TRANSFORMGRADIENTARCHIVE = _descriptor.Descriptor(
  name='TransformGradientArchive',
  full_name='TSD.TransformGradientArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='TSD.TransformGradientArchive.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='TSD.TransformGradientArchive.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseNaturalSize', full_name='TSD.TransformGradientArchive.baseNaturalSize', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2363,
  serialized_end=2477,
)


_GRADIENTARCHIVE_GRADIENTSTOP = _descriptor.Descriptor(
  name='GradientStop',
  full_name='TSD.GradientArchive.GradientStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='TSD.GradientArchive.GradientStop.color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fraction', full_name='TSD.GradientArchive.GradientStop.fraction', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inflection', full_name='TSD.GradientArchive.GradientStop.inflection', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2749,
  serialized_end=2828,
)

_GRADIENTARCHIVE = _descriptor.Descriptor(
  name='GradientArchive',
  full_name='TSD.GradientArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.GradientArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stops', full_name='TSD.GradientArchive.stops', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TSD.GradientArchive.opacity', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advancedGradient', full_name='TSD.GradientArchive.advancedGradient', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='anglegradient', full_name='TSD.GradientArchive.anglegradient', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transformgradient', full_name='TSD.GradientArchive.transformgradient', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GRADIENTARCHIVE_GRADIENTSTOP, ],
  enum_types=[
    _GRADIENTARCHIVE_GRADIENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2480,
  serialized_end=2868,
)


_IMAGEFILLARCHIVE = _descriptor.Descriptor(
  name='ImageFillArchive',
  full_name='TSD.ImageFillArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='imagedata', full_name='TSD.ImageFillArchive.imagedata', index=0,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='technique', full_name='TSD.ImageFillArchive.technique', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tint', full_name='TSD.ImageFillArchive.tint', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fillsize', full_name='TSD.ImageFillArchive.fillsize', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='originalimagedata', full_name='TSD.ImageFillArchive.originalimagedata', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interpretsUntaggedImageDataAsGeneric', full_name='TSD.ImageFillArchive.interpretsUntaggedImageDataAsGeneric', index=5,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referencecolor', full_name='TSD.ImageFillArchive.referencecolor', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_imagedata', full_name='TSD.ImageFillArchive.database_imagedata', index=7,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_originalimagedata', full_name='TSD.ImageFillArchive.database_originalimagedata', index=8,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGEFILLARCHIVE_IMAGEFILLTECHNIQUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2871,
  serialized_end=3368,
)


_FILLARCHIVE = _descriptor.Descriptor(
  name='FillArchive',
  full_name='TSD.FillArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='TSD.FillArchive.color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gradient', full_name='TSD.FillArchive.gradient', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='TSD.FillArchive.image', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(100, 536870912), ],
  oneofs=[
  ],
  serialized_start=3371,
  serialized_end=3499,
)


_STROKEPATTERNARCHIVE = _descriptor.Descriptor(
  name='StrokePatternArchive',
  full_name='TSD.StrokePatternArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.StrokePatternArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='TSD.StrokePatternArchive.phase', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='TSD.StrokePatternArchive.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='TSD.StrokePatternArchive.pattern', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STROKEPATTERNARCHIVE_STROKEPATTERNTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3502,
  serialized_end=3709,
)


_STROKEARCHIVE = _descriptor.Descriptor(
  name='StrokeArchive',
  full_name='TSD.StrokeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='TSD.StrokeArchive.color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='TSD.StrokeArchive.width', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cap', full_name='TSD.StrokeArchive.cap', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='join', full_name='TSD.StrokeArchive.join', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='miter_limit', full_name='TSD.StrokeArchive.miter_limit', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='TSD.StrokeArchive.pattern', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smart_stroke', full_name='TSD.StrokeArchive.smart_stroke', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame', full_name='TSD.StrokeArchive.frame', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='patterned_stroke', full_name='TSD.StrokeArchive.patterned_stroke', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STROKEARCHIVE_LINECAP,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3712,
  serialized_end=4093,
)


_SMARTSTROKEARCHIVE = _descriptor.Descriptor(
  name='SmartStrokeArchive',
  full_name='TSD.SmartStrokeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stroke_name', full_name='TSD.SmartStrokeArchive.stroke_name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='random_seed', full_name='TSD.SmartStrokeArchive.random_seed', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterValues', full_name='TSD.SmartStrokeArchive.parameterValues', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern_offset_distance', full_name='TSD.SmartStrokeArchive.pattern_offset_distance', index=3,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4096,
  serialized_end=4242,
)


_FRAMEARCHIVE = _descriptor.Descriptor(
  name='FrameArchive',
  full_name='TSD.FrameArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frameName', full_name='TSD.FrameArchive.frameName', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assetScale', full_name='TSD.FrameArchive.assetScale', index=1,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4244,
  serialized_end=4297,
)


_PATTERNEDSTROKEARCHIVE = _descriptor.Descriptor(
  name='PatternedStrokeArchive',
  full_name='TSD.PatternedStrokeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pattern_name', full_name='TSD.PatternedStrokeArchive.pattern_name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4299,
  serialized_end=4345,
)


_LINEENDARCHIVE = _descriptor.Descriptor(
  name='LineEndArchive',
  full_name='TSD.LineEndArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='TSD.LineEndArchive.path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_join', full_name='TSD.LineEndArchive.line_join', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_point', full_name='TSD.LineEndArchive.end_point', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_filled', full_name='TSD.LineEndArchive.is_filled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSD.LineEndArchive.identifier', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4348,
  serialized_end=4493,
)


_SHADOWARCHIVE = _descriptor.Descriptor(
  name='ShadowArchive',
  full_name='TSD.ShadowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='TSD.ShadowArchive.color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle', full_name='TSD.ShadowArchive.angle', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(315),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='TSD.ShadowArchive.offset', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='radius', full_name='TSD.ShadowArchive.radius', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TSD.ShadowArchive.opacity', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='TSD.ShadowArchive.is_enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.ShadowArchive.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dropShadow', full_name='TSD.ShadowArchive.dropShadow', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contactShadow', full_name='TSD.ShadowArchive.contactShadow', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curvedShadow', full_name='TSD.ShadowArchive.curvedShadow', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SHADOWARCHIVE_SHADOWTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4496,
  serialized_end=4905,
)


_DROPSHADOWARCHIVE = _descriptor.Descriptor(
  name='DropShadowArchive',
  full_name='TSD.DropShadowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4907,
  serialized_end=4926,
)


_CONTACTSHADOWARCHIVE = _descriptor.Descriptor(
  name='ContactShadowArchive',
  full_name='TSD.ContactShadowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='TSD.ContactShadowArchive.height', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='TSD.ContactShadowArchive.offset', index=1,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4928,
  serialized_end=4987,
)


_CURVEDSHADOWARCHIVE = _descriptor.Descriptor(
  name='CurvedShadowArchive',
  full_name='TSD.CurvedShadowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='curve', full_name='TSD.CurvedShadowArchive.curve', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.6),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4989,
  serialized_end=5030,
)


_REFLECTIONARCHIVE = _descriptor.Descriptor(
  name='ReflectionArchive',
  full_name='TSD.ReflectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TSD.ReflectionArchive.opacity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5032,
  serialized_end=5073,
)


_IMAGEADJUSTMENTSARCHIVE = _descriptor.Descriptor(
  name='ImageAdjustmentsArchive',
  full_name='TSD.ImageAdjustmentsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exposure', full_name='TSD.ImageAdjustmentsArchive.exposure', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saturation', full_name='TSD.ImageAdjustmentsArchive.saturation', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contrast', full_name='TSD.ImageAdjustmentsArchive.contrast', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='highlights', full_name='TSD.ImageAdjustmentsArchive.highlights', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadows', full_name='TSD.ImageAdjustmentsArchive.shadows', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sharpness', full_name='TSD.ImageAdjustmentsArchive.sharpness', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='denoise', full_name='TSD.ImageAdjustmentsArchive.denoise', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='TSD.ImageAdjustmentsArchive.temperature', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tint', full_name='TSD.ImageAdjustmentsArchive.tint', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_level', full_name='TSD.ImageAdjustmentsArchive.bottom_level', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_level', full_name='TSD.ImageAdjustmentsArchive.top_level', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gamma', full_name='TSD.ImageAdjustmentsArchive.gamma', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enhance', full_name='TSD.ImageAdjustmentsArchive.enhance', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='represents_sage_adjustments', full_name='TSD.ImageAdjustmentsArchive.represents_sage_adjustments', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5076,
  serialized_end=5378,
)


_SHAPESTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='ShapeStylePropertiesArchive',
  full_name='TSD.ShapeStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fill', full_name='TSD.ShapeStylePropertiesArchive.fill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke', full_name='TSD.ShapeStylePropertiesArchive.stroke', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TSD.ShapeStylePropertiesArchive.opacity', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow', full_name='TSD.ShapeStylePropertiesArchive.shadow', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reflection', full_name='TSD.ShapeStylePropertiesArchive.reflection', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='head_line_end', full_name='TSD.ShapeStylePropertiesArchive.head_line_end', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tail_line_end', full_name='TSD.ShapeStylePropertiesArchive.tail_line_end', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5381,
  serialized_end=5663,
)


_SHAPESTYLEARCHIVE = _descriptor.Descriptor(
  name='ShapeStyleArchive',
  full_name='TSD.ShapeStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ShapeStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TSD.ShapeStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape_properties', full_name='TSD.ShapeStyleArchive.shape_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5666,
  serialized_end=5803,
)


_MEDIASTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='MediaStylePropertiesArchive',
  full_name='TSD.MediaStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stroke', full_name='TSD.MediaStylePropertiesArchive.stroke', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TSD.MediaStylePropertiesArchive.opacity', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow', full_name='TSD.MediaStylePropertiesArchive.shadow', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reflection', full_name='TSD.MediaStylePropertiesArchive.reflection', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5806,
  serialized_end=5968,
)


_MEDIASTYLEARCHIVE = _descriptor.Descriptor(
  name='MediaStyleArchive',
  full_name='TSD.MediaStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.MediaStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TSD.MediaStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_properties', full_name='TSD.MediaStyleArchive.media_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5971,
  serialized_end=6108,
)


_THEMEPRESETSARCHIVE = _descriptor.Descriptor(
  name='ThemePresetsArchive',
  full_name='TSD.ThemePresetsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gradient_fill_presets', full_name='TSD.ThemePresetsArchive.gradient_fill_presets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_fill_presets', full_name='TSD.ThemePresetsArchive.image_fill_presets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow_presets', full_name='TSD.ThemePresetsArchive.shadow_presets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_style_presets', full_name='TSD.ThemePresetsArchive.line_style_presets', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape_style_presets', full_name='TSD.ThemePresetsArchive.shape_style_presets', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='textbox_style_presets', full_name='TSD.ThemePresetsArchive.textbox_style_presets', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_style_presets', full_name='TSD.ThemePresetsArchive.image_style_presets', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movie_style_presets', full_name='TSD.ThemePresetsArchive.movie_style_presets', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawing_line_style_presets', full_name='TSD.ThemePresetsArchive.drawing_line_style_presets', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='extension', full_name='TSD.ThemePresetsArchive.extension', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6111,
  serialized_end=6613,
)


_THEMEREPLACEFILLPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ThemeReplaceFillPresetCommandArchive',
  full_name='TSD.ThemeReplaceFillPresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ThemeReplaceFillPresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TSD.ThemeReplaceFillPresetCommandArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill', full_name='TSD.ThemeReplaceFillPresetCommandArchive.fill', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_fill', full_name='TSD.ThemeReplaceFillPresetCommandArchive.old_fill', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='TSD.ThemeReplaceFillPresetCommandArchive.index', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6616,
  serialized_end=6804,
)


_DRAWABLEARCHIVE = _descriptor.Descriptor(
  name='DrawableArchive',
  full_name='TSD.DrawableArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geometry', full_name='TSD.DrawableArchive.geometry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='TSD.DrawableArchive.parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exterior_text_wrap', full_name='TSD.DrawableArchive.exterior_text_wrap', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hyperlink_url', full_name='TSD.DrawableArchive.hyperlink_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locked', full_name='TSD.DrawableArchive.locked', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='TSD.DrawableArchive.comment', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aspect_ratio_locked', full_name='TSD.DrawableArchive.aspect_ratio_locked', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accessibility_description', full_name='TSD.DrawableArchive.accessibility_description', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_annotations', full_name='TSD.DrawableArchive.pencil_annotations', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='TSD.DrawableArchive.title', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption', full_name='TSD.DrawableArchive.caption', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title_hidden', full_name='TSD.DrawableArchive.title_hidden', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_hidden', full_name='TSD.DrawableArchive.caption_hidden', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6807,
  serialized_end=7244,
)


_CONTAINERARCHIVE = _descriptor.Descriptor(
  name='ContainerArchive',
  full_name='TSD.ContainerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geometry', full_name='TSD.ContainerArchive.geometry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='TSD.ContainerArchive.parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='TSD.ContainerArchive.children', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7246,
  serialized_end=7370,
)


_GROUPARCHIVE = _descriptor.Descriptor(
  name='GroupArchive',
  full_name='TSD.GroupArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.GroupArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='TSD.GroupArchive.children', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fake_shape_for_empty_group', full_name='TSD.GroupArchive.fake_shape_for_empty_group', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(100, 536870912), ],
  oneofs=[
  ],
  serialized_start=7373,
  serialized_end=7520,
)


_FREEHANDDRAWINGANIMATIONARCHIVE = _descriptor.Descriptor(
  name='FreehandDrawingAnimationArchive',
  full_name='TSD.FreehandDrawingAnimationArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='TSD.FreehandDrawingAnimationArchive.duration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_loop', full_name='TSD.FreehandDrawingAnimationArchive.should_loop', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7522,
  serialized_end=7594,
)


_FREEHANDDRAWINGARCHIVE = _descriptor.Descriptor(
  name='FreehandDrawingArchive',
  full_name='TSD.FreehandDrawingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spacer_shape', full_name='TSD.FreehandDrawingArchive.spacer_shape', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TSD.FreehandDrawingArchive.opacity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='animation', full_name='TSD.FreehandDrawingArchive.animation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='freehand_drawing_archive', full_name='TSD.FreehandDrawingArchive.freehand_drawing_archive', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7597,
  serialized_end=7815,
)


_SHAPEARCHIVE = _descriptor.Descriptor(
  name='ShapeArchive',
  full_name='TSD.ShapeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ShapeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSD.ShapeArchive.style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pathsource', full_name='TSD.ShapeArchive.pathsource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='head_line_end', full_name='TSD.ShapeArchive.head_line_end', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tail_line_end', full_name='TSD.ShapeArchive.tail_line_end', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strokePatternOffsetDistance', full_name='TSD.ShapeArchive.strokePatternOffsetDistance', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7818,
  serialized_end=8077,
)


_CONNECTIONLINEARCHIVE = _descriptor.Descriptor(
  name='ConnectionLineArchive',
  full_name='TSD.ConnectionLineArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ConnectionLineArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connected_from', full_name='TSD.ConnectionLineArchive.connected_from', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connected_to', full_name='TSD.ConnectionLineArchive.connected_to', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connected_to_uuid', full_name='TSD.ConnectionLineArchive.connected_to_uuid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connected_from_uuid', full_name='TSD.ConnectionLineArchive.connected_from_uuid', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8080,
  serialized_end=8293,
)


_IMAGEARCHIVE = _descriptor.Descriptor(
  name='ImageArchive',
  full_name='TSD.ImageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ImageArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='TSD.ImageArchive.data', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSD.ImageArchive.style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='originalSize', full_name='TSD.ImageArchive.originalSize', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='TSD.ImageArchive.mask', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnailData', full_name='TSD.ImageArchive.thumbnailData', index=5,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='TSD.ImageArchive.flags', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='originalData', full_name='TSD.ImageArchive.originalData', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='naturalSize', full_name='TSD.ImageArchive.naturalSize', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instantAlphaPath', full_name='TSD.ImageArchive.instantAlphaPath', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imageAdjustments', full_name='TSD.ImageArchive.imageAdjustments', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enhancedImageData', full_name='TSD.ImageArchive.enhancedImageData', index=11,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjustedImageData', full_name='TSD.ImageArchive.adjustedImageData', index=12,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnailAdjustedImageData', full_name='TSD.ImageArchive.thumbnailAdjustedImageData', index=13,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interpretsUntaggedImageDataAsGeneric', full_name='TSD.ImageArchive.interpretsUntaggedImageDataAsGeneric', index=14,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_data', full_name='TSD.ImageArchive.database_data', index=15,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_thumbnailData', full_name='TSD.ImageArchive.database_thumbnailData', index=16,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_originalData', full_name='TSD.ImageArchive.database_originalData', index=17,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traced_path', full_name='TSD.ImageArchive.traced_path', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribution', full_name='TSD.ImageArchive.attribution', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_trace_pdf_content', full_name='TSD.ImageArchive.should_trace_pdf_content', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(100, 1000), ],
  oneofs=[
  ],
  serialized_start=8296,
  serialized_end=9142,
)


_MASKARCHIVE = _descriptor.Descriptor(
  name='MaskArchive',
  full_name='TSD.MaskArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.MaskArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pathsource', full_name='TSD.MaskArchive.pathsource', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9144,
  serialized_end=9238,
)


_IMAGEDATAATTRIBUTES = _descriptor.Descriptor(
  name='ImageDataAttributes',
  full_name='TSD.ImageDataAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pixel_size', full_name='TSD.ImageDataAttributes.pixel_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_is_srgb', full_name='TSD.ImageDataAttributes.image_is_srgb', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_be_interpreted_as_generic_if_untagged', full_name='TSD.ImageDataAttributes.should_be_interpreted_as_generic_if_untagged', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='image_data_attributes', full_name='TSD.ImageDataAttributes.image_data_attributes', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9241,
  serialized_end=9448,
)


_MOVIEARCHIVE = _descriptor.Descriptor(
  name='MovieArchive',
  full_name='TSD.MovieArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.MovieArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movieData', full_name='TSD.MovieArchive.movieData', index=1,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='importedAuxiliaryMovieData', full_name='TSD.MovieArchive.importedAuxiliaryMovieData', index=2,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imported_auxiliary_movie_data_original_filename', full_name='TSD.MovieArchive.imported_auxiliary_movie_data_original_filename', index=3,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movieRemoteURL', full_name='TSD.MovieArchive.movieRemoteURL', index=4,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='TSD.MovieArchive.startTime', index=5,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='TSD.MovieArchive.endTime', index=6,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posterTime', full_name='TSD.MovieArchive.posterTime', index=7,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loopOptionAsInteger', full_name='TSD.MovieArchive.loopOptionAsInteger', index=8,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loop_option', full_name='TSD.MovieArchive.loop_option', index=9,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='TSD.MovieArchive.volume', index=10,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='autoPlay', full_name='TSD.MovieArchive.autoPlay', index=11,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audioOnly', full_name='TSD.MovieArchive.audioOnly', index=12,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streaming', full_name='TSD.MovieArchive.streaming', index=13,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nativeAudioRecording', full_name='TSD.MovieArchive.nativeAudioRecording', index=14,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='playsAcrossSlides', full_name='TSD.MovieArchive.playsAcrossSlides', index=15,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posterImageData', full_name='TSD.MovieArchive.posterImageData', index=16,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audioOnlyImageData', full_name='TSD.MovieArchive.audioOnlyImageData', index=17,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='poster_image_generated_with_alpha_support', full_name='TSD.MovieArchive.poster_image_generated_with_alpha_support', index=18,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='playableState', full_name='TSD.MovieArchive.playableState', index=19,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='TSD.MovieArchive.flags', index=20,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_movieData', full_name='TSD.MovieArchive.database_movieData', index=21,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_posterImageData', full_name='TSD.MovieArchive.database_posterImageData', index=22,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_audioOnlyImageData', full_name='TSD.MovieArchive.database_audioOnlyImageData', index=23,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSD.MovieArchive.style', index=24,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='originalSize', full_name='TSD.MovieArchive.originalSize', index=25,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='naturalSize', full_name='TSD.MovieArchive.naturalSize', index=26,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribution', full_name='TSD.MovieArchive.attribution', index=27,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='TSD.MovieArchive.fingerprint', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOVIEARCHIVE_MOVIELOOPOPTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9451,
  serialized_end=10523,
)


_EXTERIORTEXTWRAPARCHIVE = _descriptor.Descriptor(
  name='ExteriorTextWrapArchive',
  full_name='TSD.ExteriorTextWrapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.ExteriorTextWrapArchive.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='TSD.ExteriorTextWrapArchive.direction', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fit_type', full_name='TSD.ExteriorTextWrapArchive.fit_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margin', full_name='TSD.ExteriorTextWrapArchive.margin', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alpha_threshold', full_name='TSD.ExteriorTextWrapArchive.alpha_threshold', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_html_wrap', full_name='TSD.ExteriorTextWrapArchive.is_html_wrap', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10526,
  serialized_end=10665,
)


_DRAWABLECONTENTDESCRIPTION = _descriptor.Descriptor(
  name='DrawableContentDescription',
  full_name='TSD.DrawableContentDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element_kind', full_name='TSD.DrawableContentDescription.element_kind', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_anchored_to_text', full_name='TSD.DrawableContentDescription.is_anchored_to_text', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_floating_above_text', full_name='TSD.DrawableContentDescription.is_floating_above_text', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_inline_with_text', full_name='TSD.DrawableContentDescription.is_inline_with_text', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10668,
  serialized_end=10808,
)


_FREEHANDDRAWINGCONTENTDESCRIPTION = _descriptor.Descriptor(
  name='FreehandDrawingContentDescription',
  full_name='TSD.FreehandDrawingContentDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.FreehandDrawingContentDescription.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_doc_wanted_spacer_shape', full_name='TSD.FreehandDrawingContentDescription.source_doc_wanted_spacer_shape', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10810,
  serialized_end=10933,
)


_FREEHANDDRAWINGTOOLKITUISTATE = _descriptor.Descriptor(
  name='FreehandDrawingToolkitUIState',
  full_name='TSD.FreehandDrawingToolkitUIState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_color', full_name='TSD.FreehandDrawingToolkitUIState.current_color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='most_recent_pen_tool_type', full_name='TSD.FreehandDrawingToolkitUIState.most_recent_pen_tool_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pen_tool_opacity', full_name='TSD.FreehandDrawingToolkitUIState.pen_tool_opacity', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pen_tool_unscaled_width', full_name='TSD.FreehandDrawingToolkitUIState.pen_tool_unscaled_width', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_tool_opacity', full_name='TSD.FreehandDrawingToolkitUIState.pencil_tool_opacity', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_tool_unscaled_width', full_name='TSD.FreehandDrawingToolkitUIState.pencil_tool_unscaled_width', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crayon_tool_opacity', full_name='TSD.FreehandDrawingToolkitUIState.crayon_tool_opacity', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crayon_tool_unscaled_width', full_name='TSD.FreehandDrawingToolkitUIState.crayon_tool_unscaled_width', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_tool_opacity', full_name='TSD.FreehandDrawingToolkitUIState.fill_tool_opacity', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eraser_tool_scaled_width', full_name='TSD.FreehandDrawingToolkitUIState.eraser_tool_scaled_width', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eraser_tool_erases_whole_objects', full_name='TSD.FreehandDrawingToolkitUIState.eraser_tool_erases_whole_objects', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pen_tool_color', full_name='TSD.FreehandDrawingToolkitUIState.pen_tool_color', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_tool_color', full_name='TSD.FreehandDrawingToolkitUIState.pencil_tool_color', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crayon_tool_color', full_name='TSD.FreehandDrawingToolkitUIState.crayon_tool_color', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_tool_color', full_name='TSD.FreehandDrawingToolkitUIState.fill_tool_color', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FREEHANDDRAWINGTOOLKITUISTATE_FREEHANDDRAWINGTOOLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10936,
  serialized_end=11614,
)


_STANDINCAPTIONARCHIVE = _descriptor.Descriptor(
  name='StandinCaptionArchive',
  full_name='TSD.StandinCaptionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11616,
  serialized_end=11639,
)


_GUIDEARCHIVE = _descriptor.Descriptor(
  name='GuideArchive',
  full_name='TSD.GuideArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.GuideArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='TSD.GuideArchive.offset', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='TSD.GuideArchive.start', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='TSD.GuideArchive.end', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamic', full_name='TSD.GuideArchive.dynamic', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infinite', full_name='TSD.GuideArchive.infinite', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GUIDEARCHIVE_GUIDETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11642,
  serialized_end=11821,
)


_USERDEFINEDGUIDEARCHIVE = _descriptor.Descriptor(
  name='UserDefinedGuideArchive',
  full_name='TSD.UserDefinedGuideArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.UserDefinedGuideArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='TSD.UserDefinedGuideArchive.position', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERDEFINEDGUIDEARCHIVE_GUIDETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11824,
  serialized_end=11964,
)


_GUIDESTORAGEARCHIVE = _descriptor.Descriptor(
  name='GuideStorageArchive',
  full_name='TSD.GuideStorageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userDefinedGuides', full_name='TSD.GuideStorageArchive.userDefinedGuides', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11966,
  serialized_end=12044,
)


_CANVASSELECTIONARCHIVE = _descriptor.Descriptor(
  name='CanvasSelectionArchive',
  full_name='TSD.CanvasSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='infos', full_name='TSD.CanvasSelectionArchive.infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_interactive_infos', full_name='TSD.CanvasSelectionArchive.non_interactive_infos', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container', full_name='TSD.CanvasSelectionArchive.container', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12047,
  serialized_end=12188,
)


_DRAWABLESELECTIONARCHIVE = _descriptor.Descriptor(
  name='DrawableSelectionArchive',
  full_name='TSD.DrawableSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='infos', full_name='TSD.DrawableSelectionArchive.infos', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_interactive_infos', full_name='TSD.DrawableSelectionArchive.non_interactive_infos', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12190,
  serialized_end=12294,
)


_GROUPSELECTIONARCHIVE = _descriptor.Descriptor(
  name='GroupSelectionArchive',
  full_name='TSD.GroupSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.GroupSelectionArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_selected_infos_in_non_group_container', full_name='TSD.GroupSelectionArchive.has_selected_infos_in_non_group_container', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12296,
  serialized_end=12416,
)


_PATHSELECTIONARCHIVE = _descriptor.Descriptor(
  name='PathSelectionArchive',
  full_name='TSD.PathSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12418,
  serialized_end=12440,
)


_INFOHYPERLINKSELECTIONARCHIVE = _descriptor.Descriptor(
  name='InfoHyperlinkSelectionArchive',
  full_name='TSD.InfoHyperlinkSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12442,
  serialized_end=12473,
)


_COMMENTSTORAGEARCHIVE = _descriptor.Descriptor(
  name='CommentStorageArchive',
  full_name='TSD.CommentStorageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='TSD.CommentStorageArchive.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_date', full_name='TSD.CommentStorageArchive.creation_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='author', full_name='TSD.CommentStorageArchive.author', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replies', full_name='TSD.CommentStorageArchive.replies', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12476,
  serialized_end=12612,
)


_REPLACEANNOTATIONAUTHORCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ReplaceAnnotationAuthorCommandArchive',
  full_name='TSD.ReplaceAnnotationAuthorCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ReplaceAnnotationAuthorCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_annotation_author', full_name='TSD.ReplaceAnnotationAuthorCommandArchive.old_annotation_author', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_annotation_author', full_name='TSD.ReplaceAnnotationAuthorCommandArchive.new_annotation_author', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12615,
  serialized_end=12784,
)


_PENCILANNOTATIONARCHIVE = _descriptor.Descriptor(
  name='PencilAnnotationArchive',
  full_name='TSD.PencilAnnotationArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pencil_annotation_storage', full_name='TSD.PencilAnnotationArchive.pencil_annotation_storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12786,
  serialized_end=12862,
)


_PENCILANNOTATIONSELECTIONARCHIVE = _descriptor.Descriptor(
  name='PencilAnnotationSelectionArchive',
  full_name='TSD.PencilAnnotationSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pencil_annotation', full_name='TSD.PencilAnnotationSelectionArchive.pencil_annotation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12864,
  serialized_end=12941,
)


_PENCILANNOTATIONSTORAGEARCHIVE = _descriptor.Descriptor(
  name='PencilAnnotationStorageArchive',
  full_name='TSD.PencilAnnotationStorageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attached_location', full_name='TSD.PencilAnnotationStorageArchive.attached_location', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='markup_offset', full_name='TSD.PencilAnnotationStorageArchive.markup_offset', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rasterized_image', full_name='TSD.PencilAnnotationStorageArchive.rasterized_image', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_encoded_drawing', full_name='TSD.PencilAnnotationStorageArchive.legacy_encoded_drawing', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawing_path', full_name='TSD.PencilAnnotationStorageArchive.drawing_path', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strokes_bounding_box_origin', full_name='TSD.PencilAnnotationStorageArchive.strokes_bounding_box_origin', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strokes_bounding_box_size', full_name='TSD.PencilAnnotationStorageArchive.strokes_bounding_box_size', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attached_type', full_name='TSD.PencilAnnotationStorageArchive.attached_type', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_attached_size', full_name='TSD.PencilAnnotationStorageArchive.original_attached_size', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_of_pa_contained_in_parent_rep', full_name='TSD.PencilAnnotationStorageArchive.percent_of_pa_contained_in_parent_rep', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_baselines_touched_count', full_name='TSD.PencilAnnotationStorageArchive.text_baselines_touched_count', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='visible_strokes_count', full_name='TSD.PencilAnnotationStorageArchive.visible_strokes_count', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pen_color', full_name='TSD.PencilAnnotationStorageArchive.pen_color', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tool_type', full_name='TSD.PencilAnnotationStorageArchive.tool_type', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callout_sub_storages', full_name='TSD.PencilAnnotationStorageArchive.callout_sub_storages', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_date', full_name='TSD.PencilAnnotationStorageArchive.creation_date', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_annotation_drawing_scale', full_name='TSD.PencilAnnotationStorageArchive.pencil_annotation_drawing_scale', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compound_annotation_type', full_name='TSD.PencilAnnotationStorageArchive.compound_annotation_type', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_storages', full_name='TSD.PencilAnnotationStorageArchive.sub_storages', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoded_drawing', full_name='TSD.PencilAnnotationStorageArchive.encoded_drawing', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke_points_frame_origin', full_name='TSD.PencilAnnotationStorageArchive.stroke_points_frame_origin', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke_points_frame_size', full_name='TSD.PencilAnnotationStorageArchive.stroke_points_frame_size', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rendered_frame_origin', full_name='TSD.PencilAnnotationStorageArchive.rendered_frame_origin', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rendered_frame_size', full_name='TSD.PencilAnnotationStorageArchive.rendered_frame_size', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12944,
  serialized_end=13910,
)


_SPECCOLORFILLSETCOLORARCHIVE = _descriptor.Descriptor(
  name='SpecColorFillSetColorArchive',
  full_name='TSD.SpecColorFillSetColorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='TSD.SpecColorFillSetColorArchive.color', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13912,
  serialized_end=13969,
)


_SPECFRAMESETASSETSCALEARCHIVE = _descriptor.Descriptor(
  name='SpecFrameSetAssetScaleArchive',
  full_name='TSD.SpecFrameSetAssetScaleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_scale', full_name='TSD.SpecFrameSetAssetScaleArchive.asset_scale', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13971,
  serialized_end=14023,
)


_SPECGRADIENTFILLSETANGLEARCHIVE = _descriptor.Descriptor(
  name='SpecGradientFillSetAngleArchive',
  full_name='TSD.SpecGradientFillSetAngleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle', full_name='TSD.SpecGradientFillSetAngleArchive.angle', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14025,
  serialized_end=14073,
)


_SPECIMAGEFILLSETTECHNIQUEARCHIVE = _descriptor.Descriptor(
  name='SpecImageFillSetTechniqueArchive',
  full_name='TSD.SpecImageFillSetTechniqueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='technique', full_name='TSD.SpecImageFillSetTechniqueArchive.technique', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14075,
  serialized_end=14128,
)


_SPECREFLECTIONSETOPACITYARCHIVE = _descriptor.Descriptor(
  name='SpecReflectionSetOpacityArchive',
  full_name='TSD.SpecReflectionSetOpacityArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TSD.SpecReflectionSetOpacityArchive.opacity', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14130,
  serialized_end=14180,
)


_SPECSHADOWSETANGLEARCHIVE = _descriptor.Descriptor(
  name='SpecShadowSetAngleArchive',
  full_name='TSD.SpecShadowSetAngleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle', full_name='TSD.SpecShadowSetAngleArchive.angle', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14182,
  serialized_end=14224,
)


_SPECSHADOWSETCOLORARCHIVE = _descriptor.Descriptor(
  name='SpecShadowSetColorArchive',
  full_name='TSD.SpecShadowSetColorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='TSD.SpecShadowSetColorArchive.color', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14226,
  serialized_end=14280,
)


_SPECSHADOWSETOFFSETARCHIVE = _descriptor.Descriptor(
  name='SpecShadowSetOffsetArchive',
  full_name='TSD.SpecShadowSetOffsetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='TSD.SpecShadowSetOffsetArchive.offset', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14282,
  serialized_end=14326,
)


_SPECSHADOWSETOPACITYARCHIVE = _descriptor.Descriptor(
  name='SpecShadowSetOpacityArchive',
  full_name='TSD.SpecShadowSetOpacityArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TSD.SpecShadowSetOpacityArchive.opacity', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14328,
  serialized_end=14374,
)


_SPECSHADOWSETRADIUSARCHIVE = _descriptor.Descriptor(
  name='SpecShadowSetRadiusArchive',
  full_name='TSD.SpecShadowSetRadiusArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='radius', full_name='TSD.SpecShadowSetRadiusArchive.radius', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14376,
  serialized_end=14420,
)


_SPECSTROKESETCOLORARCHIVE = _descriptor.Descriptor(
  name='SpecStrokeSetColorArchive',
  full_name='TSD.SpecStrokeSetColorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='TSD.SpecStrokeSetColorArchive.color', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14422,
  serialized_end=14476,
)


_SPECSTROKESETPATTERNARCHIVE = _descriptor.Descriptor(
  name='SpecStrokeSetPatternArchive',
  full_name='TSD.SpecStrokeSetPatternArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_cap', full_name='TSD.SpecStrokeSetPatternArchive.line_cap', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_join', full_name='TSD.SpecStrokeSetPatternArchive.line_join', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='miter_limit', full_name='TSD.SpecStrokeSetPatternArchive.miter_limit', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='TSD.SpecStrokeSetPatternArchive.width', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='TSD.SpecStrokeSetPatternArchive.color', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='TSD.SpecStrokeSetPatternArchive.pattern', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14479,
  serialized_end=14652,
)


_SPECSTROKESETWIDTHARCHIVE = _descriptor.Descriptor(
  name='SpecStrokeSetWidthArchive',
  full_name='TSD.SpecStrokeSetWidthArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='TSD.SpecStrokeSetWidthArchive.width', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14654,
  serialized_end=14696,
)


_ATTRIBUTION = _descriptor.Descriptor(
  name='Attribution',
  full_name='TSD.Attribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='TSD.Attribution.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_text', full_name='TSD.Attribution.description_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_url', full_name='TSD.Attribution.external_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='author_name', full_name='TSD.Attribution.author_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='author_url', full_name='TSD.Attribution.author_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14698,
  serialized_end=14815,
)


_MOVIEFINGERPRINT = _descriptor.Descriptor(
  name='MovieFingerprint',
  full_name='TSD.MovieFingerprint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracks', full_name='TSD.MovieFingerprint.tracks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='TSD.MovieFingerprint.version', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14817,
  serialized_end=14896,
)


_MOVIEFINGERPRINTTRACK = _descriptor.Descriptor(
  name='MovieFingerprintTrack',
  full_name='TSD.MovieFingerprintTrack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='media_type', full_name='TSD.MovieFingerprintTrack.media_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='TSD.MovieFingerprintTrack.enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_sample_data_length', full_name='TSD.MovieFingerprintTrack.total_sample_data_length', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_data_digest_string', full_name='TSD.MovieFingerprintTrack.sample_data_digest_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_range_start_value', full_name='TSD.MovieFingerprintTrack.time_range_start_value', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_range_start_timescale', full_name='TSD.MovieFingerprintTrack.time_range_start_timescale', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_range_start_is_valid', full_name='TSD.MovieFingerprintTrack.time_range_start_is_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_range_duration_value', full_name='TSD.MovieFingerprintTrack.time_range_duration_value', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_range_duration_timescale', full_name='TSD.MovieFingerprintTrack.time_range_duration_timescale', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_range_duration_is_valid', full_name='TSD.MovieFingerprintTrack.time_range_duration_is_valid', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='natural_size', full_name='TSD.MovieFingerprintTrack.natural_size', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_transform_a', full_name='TSD.MovieFingerprintTrack.preferred_transform_a', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_transform_b', full_name='TSD.MovieFingerprintTrack.preferred_transform_b', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_transform_c', full_name='TSD.MovieFingerprintTrack.preferred_transform_c', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_transform_d', full_name='TSD.MovieFingerprintTrack.preferred_transform_d', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_transform_tx', full_name='TSD.MovieFingerprintTrack.preferred_transform_tx', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_transform_ty', full_name='TSD.MovieFingerprintTrack.preferred_transform_ty', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_volume', full_name='TSD.MovieFingerprintTrack.preferred_volume', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='TSD.MovieFingerprintTrack.language_code', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extended_language_tag', full_name='TSD.MovieFingerprintTrack.extended_language_tag', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14899,
  serialized_end=15544,
)

_GEOMETRYARCHIVE.fields_by_name['position'].message_type = TSPMessages__pb2._POINT
_GEOMETRYARCHIVE.fields_by_name['size'].message_type = TSPMessages__pb2._SIZE
_POINTPATHSOURCEARCHIVE.fields_by_name['type'].enum_type = _POINTPATHSOURCEARCHIVE_POINTPATHSOURCETYPE
_POINTPATHSOURCEARCHIVE.fields_by_name['point'].message_type = TSPMessages__pb2._POINT
_POINTPATHSOURCEARCHIVE.fields_by_name['naturalSize'].message_type = TSPMessages__pb2._SIZE
_POINTPATHSOURCEARCHIVE_POINTPATHSOURCETYPE.containing_type = _POINTPATHSOURCEARCHIVE
_SCALARPATHSOURCEARCHIVE.fields_by_name['type'].enum_type = _SCALARPATHSOURCEARCHIVE_SCALARPATHSOURCETYPE
_SCALARPATHSOURCEARCHIVE.fields_by_name['naturalSize'].message_type = TSPMessages__pb2._SIZE
_SCALARPATHSOURCEARCHIVE_SCALARPATHSOURCETYPE.containing_type = _SCALARPATHSOURCEARCHIVE
_BEZIERPATHSOURCEARCHIVE.fields_by_name['naturalSize'].message_type = TSPMessages__pb2._SIZE
_BEZIERPATHSOURCEARCHIVE.fields_by_name['path'].message_type = TSPMessages__pb2._PATH
_CALLOUTPATHSOURCEARCHIVE.fields_by_name['natural_size'].message_type = TSPMessages__pb2._SIZE
_CALLOUTPATHSOURCEARCHIVE.fields_by_name['tail_position'].message_type = TSPMessages__pb2._POINT
_CONNECTIONLINEPATHSOURCEARCHIVE.fields_by_name['super'].message_type = _BEZIERPATHSOURCEARCHIVE
_CONNECTIONLINEPATHSOURCEARCHIVE.fields_by_name['type'].enum_type = _CONNECTIONLINEPATHSOURCEARCHIVE_CONNECTIONLINEPATHSOURCETYPE
_CONNECTIONLINEPATHSOURCEARCHIVE_CONNECTIONLINEPATHSOURCETYPE.containing_type = _CONNECTIONLINEPATHSOURCEARCHIVE
_EDITABLEBEZIERPATHSOURCEARCHIVE_NODE.fields_by_name['inControlPoint'].message_type = TSPMessages__pb2._POINT
_EDITABLEBEZIERPATHSOURCEARCHIVE_NODE.fields_by_name['nodePoint'].message_type = TSPMessages__pb2._POINT
_EDITABLEBEZIERPATHSOURCEARCHIVE_NODE.fields_by_name['outControlPoint'].message_type = TSPMessages__pb2._POINT
_EDITABLEBEZIERPATHSOURCEARCHIVE_NODE.fields_by_name['type'].enum_type = _EDITABLEBEZIERPATHSOURCEARCHIVE_NODETYPE
_EDITABLEBEZIERPATHSOURCEARCHIVE_NODE.containing_type = _EDITABLEBEZIERPATHSOURCEARCHIVE
_EDITABLEBEZIERPATHSOURCEARCHIVE_SUBPATH.fields_by_name['nodes'].message_type = _EDITABLEBEZIERPATHSOURCEARCHIVE_NODE
_EDITABLEBEZIERPATHSOURCEARCHIVE_SUBPATH.containing_type = _EDITABLEBEZIERPATHSOURCEARCHIVE
_EDITABLEBEZIERPATHSOURCEARCHIVE.fields_by_name['subpaths'].message_type = _EDITABLEBEZIERPATHSOURCEARCHIVE_SUBPATH
_EDITABLEBEZIERPATHSOURCEARCHIVE.fields_by_name['naturalSize'].message_type = TSPMessages__pb2._SIZE
_EDITABLEBEZIERPATHSOURCEARCHIVE_NODETYPE.containing_type = _EDITABLEBEZIERPATHSOURCEARCHIVE
_PATHSOURCEARCHIVE.fields_by_name['point_path_source'].message_type = _POINTPATHSOURCEARCHIVE
_PATHSOURCEARCHIVE.fields_by_name['scalar_path_source'].message_type = _SCALARPATHSOURCEARCHIVE
_PATHSOURCEARCHIVE.fields_by_name['bezier_path_source'].message_type = _BEZIERPATHSOURCEARCHIVE
_PATHSOURCEARCHIVE.fields_by_name['callout_path_source'].message_type = _CALLOUTPATHSOURCEARCHIVE
_PATHSOURCEARCHIVE.fields_by_name['connection_line_path_source'].message_type = _CONNECTIONLINEPATHSOURCEARCHIVE
_PATHSOURCEARCHIVE.fields_by_name['editable_bezier_path_source'].message_type = _EDITABLEBEZIERPATHSOURCEARCHIVE
_TRANSFORMGRADIENTARCHIVE.fields_by_name['start'].message_type = TSPMessages__pb2._POINT
_TRANSFORMGRADIENTARCHIVE.fields_by_name['end'].message_type = TSPMessages__pb2._POINT
_TRANSFORMGRADIENTARCHIVE.fields_by_name['baseNaturalSize'].message_type = TSPMessages__pb2._SIZE
_GRADIENTARCHIVE_GRADIENTSTOP.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_GRADIENTARCHIVE_GRADIENTSTOP.containing_type = _GRADIENTARCHIVE
_GRADIENTARCHIVE.fields_by_name['type'].enum_type = _GRADIENTARCHIVE_GRADIENTTYPE
_GRADIENTARCHIVE.fields_by_name['stops'].message_type = _GRADIENTARCHIVE_GRADIENTSTOP
_GRADIENTARCHIVE.fields_by_name['anglegradient'].message_type = _ANGLEGRADIENTARCHIVE
_GRADIENTARCHIVE.fields_by_name['transformgradient'].message_type = _TRANSFORMGRADIENTARCHIVE
_GRADIENTARCHIVE_GRADIENTTYPE.containing_type = _GRADIENTARCHIVE
_IMAGEFILLARCHIVE.fields_by_name['imagedata'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEFILLARCHIVE.fields_by_name['technique'].enum_type = _IMAGEFILLARCHIVE_IMAGEFILLTECHNIQUE
_IMAGEFILLARCHIVE.fields_by_name['tint'].message_type = TSPMessages__pb2._COLOR
_IMAGEFILLARCHIVE.fields_by_name['fillsize'].message_type = TSPMessages__pb2._SIZE
_IMAGEFILLARCHIVE.fields_by_name['originalimagedata'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEFILLARCHIVE.fields_by_name['referencecolor'].message_type = TSPMessages__pb2._COLOR
_IMAGEFILLARCHIVE.fields_by_name['database_imagedata'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEFILLARCHIVE.fields_by_name['database_originalimagedata'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEFILLARCHIVE_IMAGEFILLTECHNIQUE.containing_type = _IMAGEFILLARCHIVE
_FILLARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_FILLARCHIVE.fields_by_name['gradient'].message_type = _GRADIENTARCHIVE
_FILLARCHIVE.fields_by_name['image'].message_type = _IMAGEFILLARCHIVE
_STROKEPATTERNARCHIVE.fields_by_name['type'].enum_type = _STROKEPATTERNARCHIVE_STROKEPATTERNTYPE
_STROKEPATTERNARCHIVE_STROKEPATTERNTYPE.containing_type = _STROKEPATTERNARCHIVE
_STROKEARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_STROKEARCHIVE.fields_by_name['cap'].enum_type = _STROKEARCHIVE_LINECAP
_STROKEARCHIVE.fields_by_name['join'].enum_type = _LINEJOIN
_STROKEARCHIVE.fields_by_name['pattern'].message_type = _STROKEPATTERNARCHIVE
_STROKEARCHIVE.fields_by_name['smart_stroke'].message_type = _SMARTSTROKEARCHIVE
_STROKEARCHIVE.fields_by_name['frame'].message_type = _FRAMEARCHIVE
_STROKEARCHIVE.fields_by_name['patterned_stroke'].message_type = _PATTERNEDSTROKEARCHIVE
_STROKEARCHIVE_LINECAP.containing_type = _STROKEARCHIVE
_SMARTSTROKEARCHIVE.fields_by_name['parameterValues'].message_type = TSPMessages__pb2._REFERENCEDICTIONARY
_LINEENDARCHIVE.fields_by_name['path'].message_type = TSPMessages__pb2._PATH
_LINEENDARCHIVE.fields_by_name['line_join'].enum_type = _LINEJOIN
_LINEENDARCHIVE.fields_by_name['end_point'].message_type = TSPMessages__pb2._POINT
_SHADOWARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_SHADOWARCHIVE.fields_by_name['type'].enum_type = _SHADOWARCHIVE_SHADOWTYPE
_SHADOWARCHIVE.fields_by_name['dropShadow'].message_type = _DROPSHADOWARCHIVE
_SHADOWARCHIVE.fields_by_name['contactShadow'].message_type = _CONTACTSHADOWARCHIVE
_SHADOWARCHIVE.fields_by_name['curvedShadow'].message_type = _CURVEDSHADOWARCHIVE
_SHADOWARCHIVE_SHADOWTYPE.containing_type = _SHADOWARCHIVE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['fill'].message_type = _FILLARCHIVE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['stroke'].message_type = _STROKEARCHIVE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['shadow'].message_type = _SHADOWARCHIVE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['reflection'].message_type = _REFLECTIONARCHIVE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['head_line_end'].message_type = _LINEENDARCHIVE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['tail_line_end'].message_type = _LINEENDARCHIVE
_SHAPESTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_SHAPESTYLEARCHIVE.fields_by_name['shape_properties'].message_type = _SHAPESTYLEPROPERTIESARCHIVE
_MEDIASTYLEPROPERTIESARCHIVE.fields_by_name['stroke'].message_type = _STROKEARCHIVE
_MEDIASTYLEPROPERTIESARCHIVE.fields_by_name['shadow'].message_type = _SHADOWARCHIVE
_MEDIASTYLEPROPERTIESARCHIVE.fields_by_name['reflection'].message_type = _REFLECTIONARCHIVE
_MEDIASTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_MEDIASTYLEARCHIVE.fields_by_name['media_properties'].message_type = _MEDIASTYLEPROPERTIESARCHIVE
_THEMEPRESETSARCHIVE.fields_by_name['gradient_fill_presets'].message_type = _FILLARCHIVE
_THEMEPRESETSARCHIVE.fields_by_name['image_fill_presets'].message_type = _FILLARCHIVE
_THEMEPRESETSARCHIVE.fields_by_name['shadow_presets'].message_type = _SHADOWARCHIVE
_THEMEPRESETSARCHIVE.fields_by_name['line_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['shape_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['textbox_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['image_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['movie_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['drawing_line_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREPLACEFILLPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_THEMEREPLACEFILLPRESETCOMMANDARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREPLACEFILLPRESETCOMMANDARCHIVE.fields_by_name['fill'].message_type = _FILLARCHIVE
_THEMEREPLACEFILLPRESETCOMMANDARCHIVE.fields_by_name['old_fill'].message_type = _FILLARCHIVE
_DRAWABLEARCHIVE.fields_by_name['geometry'].message_type = _GEOMETRYARCHIVE
_DRAWABLEARCHIVE.fields_by_name['parent'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLEARCHIVE.fields_by_name['exterior_text_wrap'].message_type = _EXTERIORTEXTWRAPARCHIVE
_DRAWABLEARCHIVE.fields_by_name['comment'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLEARCHIVE.fields_by_name['pencil_annotations'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLEARCHIVE.fields_by_name['title'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLEARCHIVE.fields_by_name['caption'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINERARCHIVE.fields_by_name['geometry'].message_type = _GEOMETRYARCHIVE
_CONTAINERARCHIVE.fields_by_name['parent'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINERARCHIVE.fields_by_name['children'].message_type = TSPMessages__pb2._REFERENCE
_GROUPARCHIVE.fields_by_name['super'].message_type = _DRAWABLEARCHIVE
_GROUPARCHIVE.fields_by_name['children'].message_type = TSPMessages__pb2._REFERENCE
_GROUPARCHIVE.fields_by_name['fake_shape_for_empty_group'].message_type = TSPMessages__pb2._REFERENCE
_FREEHANDDRAWINGARCHIVE.fields_by_name['spacer_shape'].message_type = TSPMessages__pb2._REFERENCE
_FREEHANDDRAWINGARCHIVE.fields_by_name['animation'].message_type = _FREEHANDDRAWINGANIMATIONARCHIVE
_SHAPEARCHIVE.fields_by_name['super'].message_type = _DRAWABLEARCHIVE
_SHAPEARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_SHAPEARCHIVE.fields_by_name['pathsource'].message_type = _PATHSOURCEARCHIVE
_SHAPEARCHIVE.fields_by_name['head_line_end'].message_type = _LINEENDARCHIVE
_SHAPEARCHIVE.fields_by_name['tail_line_end'].message_type = _LINEENDARCHIVE
_CONNECTIONLINEARCHIVE.fields_by_name['super'].message_type = _SHAPEARCHIVE
_CONNECTIONLINEARCHIVE.fields_by_name['connected_from'].message_type = TSPMessages__pb2._REFERENCE
_CONNECTIONLINEARCHIVE.fields_by_name['connected_to'].message_type = TSPMessages__pb2._REFERENCE
_CONNECTIONLINEARCHIVE.fields_by_name['connected_to_uuid'].message_type = TSPMessages__pb2._UUID
_CONNECTIONLINEARCHIVE.fields_by_name['connected_from_uuid'].message_type = TSPMessages__pb2._UUID
_IMAGEARCHIVE.fields_by_name['super'].message_type = _DRAWABLEARCHIVE
_IMAGEARCHIVE.fields_by_name['data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEARCHIVE.fields_by_name['originalSize'].message_type = TSPMessages__pb2._SIZE
_IMAGEARCHIVE.fields_by_name['mask'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEARCHIVE.fields_by_name['thumbnailData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEARCHIVE.fields_by_name['originalData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEARCHIVE.fields_by_name['naturalSize'].message_type = TSPMessages__pb2._SIZE
_IMAGEARCHIVE.fields_by_name['instantAlphaPath'].message_type = TSPMessages__pb2._PATH
_IMAGEARCHIVE.fields_by_name['imageAdjustments'].message_type = _IMAGEADJUSTMENTSARCHIVE
_IMAGEARCHIVE.fields_by_name['enhancedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEARCHIVE.fields_by_name['adjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEARCHIVE.fields_by_name['thumbnailAdjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEARCHIVE.fields_by_name['database_data'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEARCHIVE.fields_by_name['database_thumbnailData'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEARCHIVE.fields_by_name['database_originalData'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEARCHIVE.fields_by_name['traced_path'].message_type = TSPMessages__pb2._PATH
_IMAGEARCHIVE.fields_by_name['attribution'].message_type = _ATTRIBUTION
_MASKARCHIVE.fields_by_name['super'].message_type = _DRAWABLEARCHIVE
_MASKARCHIVE.fields_by_name['pathsource'].message_type = _PATHSOURCEARCHIVE
_IMAGEDATAATTRIBUTES.fields_by_name['pixel_size'].message_type = TSPMessages__pb2._SIZE
_MOVIEARCHIVE.fields_by_name['super'].message_type = _DRAWABLEARCHIVE
_MOVIEARCHIVE.fields_by_name['movieData'].message_type = TSPMessages__pb2._DATAREFERENCE
_MOVIEARCHIVE.fields_by_name['importedAuxiliaryMovieData'].message_type = TSPMessages__pb2._DATAREFERENCE
_MOVIEARCHIVE.fields_by_name['loop_option'].enum_type = _MOVIEARCHIVE_MOVIELOOPOPTION
_MOVIEARCHIVE.fields_by_name['posterImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_MOVIEARCHIVE.fields_by_name['audioOnlyImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_MOVIEARCHIVE.fields_by_name['database_movieData'].message_type = TSPMessages__pb2._REFERENCE
_MOVIEARCHIVE.fields_by_name['database_posterImageData'].message_type = TSPMessages__pb2._REFERENCE
_MOVIEARCHIVE.fields_by_name['database_audioOnlyImageData'].message_type = TSPMessages__pb2._REFERENCE
_MOVIEARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_MOVIEARCHIVE.fields_by_name['originalSize'].message_type = TSPMessages__pb2._SIZE
_MOVIEARCHIVE.fields_by_name['naturalSize'].message_type = TSPMessages__pb2._SIZE
_MOVIEARCHIVE.fields_by_name['attribution'].message_type = _ATTRIBUTION
_MOVIEARCHIVE.fields_by_name['fingerprint'].message_type = _MOVIEFINGERPRINT
_MOVIEARCHIVE_MOVIELOOPOPTION.containing_type = _MOVIEARCHIVE
_FREEHANDDRAWINGCONTENTDESCRIPTION.fields_by_name['super'].message_type = _DRAWABLECONTENTDESCRIPTION
_FREEHANDDRAWINGTOOLKITUISTATE.fields_by_name['current_color'].message_type = TSPMessages__pb2._COLOR
_FREEHANDDRAWINGTOOLKITUISTATE.fields_by_name['most_recent_pen_tool_type'].enum_type = _FREEHANDDRAWINGTOOLKITUISTATE_FREEHANDDRAWINGTOOLTYPE
_FREEHANDDRAWINGTOOLKITUISTATE.fields_by_name['pen_tool_color'].message_type = TSPMessages__pb2._COLOR
_FREEHANDDRAWINGTOOLKITUISTATE.fields_by_name['pencil_tool_color'].message_type = TSPMessages__pb2._COLOR
_FREEHANDDRAWINGTOOLKITUISTATE.fields_by_name['crayon_tool_color'].message_type = TSPMessages__pb2._COLOR
_FREEHANDDRAWINGTOOLKITUISTATE.fields_by_name['fill_tool_color'].message_type = TSPMessages__pb2._COLOR
_FREEHANDDRAWINGTOOLKITUISTATE_FREEHANDDRAWINGTOOLTYPE.containing_type = _FREEHANDDRAWINGTOOLKITUISTATE
_GUIDEARCHIVE.fields_by_name['type'].enum_type = _GUIDEARCHIVE_GUIDETYPE
_GUIDEARCHIVE_GUIDETYPE.containing_type = _GUIDEARCHIVE
_USERDEFINEDGUIDEARCHIVE.fields_by_name['type'].enum_type = _USERDEFINEDGUIDEARCHIVE_GUIDETYPE
_USERDEFINEDGUIDEARCHIVE_GUIDETYPE.containing_type = _USERDEFINEDGUIDEARCHIVE
_GUIDESTORAGEARCHIVE.fields_by_name['userDefinedGuides'].message_type = _USERDEFINEDGUIDEARCHIVE
_CANVASSELECTIONARCHIVE.fields_by_name['infos'].message_type = TSPMessages__pb2._REFERENCE
_CANVASSELECTIONARCHIVE.fields_by_name['non_interactive_infos'].message_type = TSPMessages__pb2._REFERENCE
_CANVASSELECTIONARCHIVE.fields_by_name['container'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLESELECTIONARCHIVE.fields_by_name['infos'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLESELECTIONARCHIVE.fields_by_name['non_interactive_infos'].message_type = TSPMessages__pb2._REFERENCE
_GROUPSELECTIONARCHIVE.fields_by_name['super'].message_type = _DRAWABLESELECTIONARCHIVE
_COMMENTSTORAGEARCHIVE.fields_by_name['creation_date'].message_type = TSPMessages__pb2._DATE
_COMMENTSTORAGEARCHIVE.fields_by_name['author'].message_type = TSPMessages__pb2._REFERENCE
_COMMENTSTORAGEARCHIVE.fields_by_name['replies'].message_type = TSPMessages__pb2._REFERENCE
_REPLACEANNOTATIONAUTHORCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_REPLACEANNOTATIONAUTHORCOMMANDARCHIVE.fields_by_name['old_annotation_author'].message_type = TSPMessages__pb2._REFERENCE
_REPLACEANNOTATIONAUTHORCOMMANDARCHIVE.fields_by_name['new_annotation_author'].message_type = TSPMessages__pb2._REFERENCE
_PENCILANNOTATIONARCHIVE.fields_by_name['pencil_annotation_storage'].message_type = TSPMessages__pb2._REFERENCE
_PENCILANNOTATIONSELECTIONARCHIVE.fields_by_name['pencil_annotation'].message_type = TSPMessages__pb2._REFERENCE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['markup_offset'].message_type = TSPMessages__pb2._POINT
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['rasterized_image'].message_type = TSPMessages__pb2._DATAREFERENCE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['legacy_encoded_drawing'].message_type = TSPMessages__pb2._DATAREFERENCE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['drawing_path'].message_type = TSPMessages__pb2._PATH
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['strokes_bounding_box_origin'].message_type = TSPMessages__pb2._POINT
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['strokes_bounding_box_size'].message_type = TSPMessages__pb2._SIZE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['original_attached_size'].message_type = TSPMessages__pb2._SIZE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['pen_color'].message_type = TSPMessages__pb2._COLOR
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['callout_sub_storages'].message_type = TSPMessages__pb2._REFERENCE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['creation_date'].message_type = TSPMessages__pb2._DATE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['sub_storages'].message_type = TSPMessages__pb2._REFERENCE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['encoded_drawing'].message_type = TSPMessages__pb2._DATAREFERENCE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['stroke_points_frame_origin'].message_type = TSPMessages__pb2._POINT
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['stroke_points_frame_size'].message_type = TSPMessages__pb2._SIZE
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['rendered_frame_origin'].message_type = TSPMessages__pb2._POINT
_PENCILANNOTATIONSTORAGEARCHIVE.fields_by_name['rendered_frame_size'].message_type = TSPMessages__pb2._SIZE
_SPECCOLORFILLSETCOLORARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_SPECSHADOWSETCOLORARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_SPECSTROKESETCOLORARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_SPECSTROKESETPATTERNARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_SPECSTROKESETPATTERNARCHIVE.fields_by_name['pattern'].message_type = _STROKEPATTERNARCHIVE
_MOVIEFINGERPRINT.fields_by_name['tracks'].message_type = _MOVIEFINGERPRINTTRACK
_MOVIEFINGERPRINTTRACK.fields_by_name['natural_size'].message_type = TSPMessages__pb2._SIZE
DESCRIPTOR.message_types_by_name['EdgeInsetsArchive'] = _EDGEINSETSARCHIVE
DESCRIPTOR.message_types_by_name['GeometryArchive'] = _GEOMETRYARCHIVE
DESCRIPTOR.message_types_by_name['PointPathSourceArchive'] = _POINTPATHSOURCEARCHIVE
DESCRIPTOR.message_types_by_name['ScalarPathSourceArchive'] = _SCALARPATHSOURCEARCHIVE
DESCRIPTOR.message_types_by_name['BezierPathSourceArchive'] = _BEZIERPATHSOURCEARCHIVE
DESCRIPTOR.message_types_by_name['CalloutPathSourceArchive'] = _CALLOUTPATHSOURCEARCHIVE
DESCRIPTOR.message_types_by_name['ConnectionLinePathSourceArchive'] = _CONNECTIONLINEPATHSOURCEARCHIVE
DESCRIPTOR.message_types_by_name['EditableBezierPathSourceArchive'] = _EDITABLEBEZIERPATHSOURCEARCHIVE
DESCRIPTOR.message_types_by_name['PathSourceArchive'] = _PATHSOURCEARCHIVE
DESCRIPTOR.message_types_by_name['AngleGradientArchive'] = _ANGLEGRADIENTARCHIVE
DESCRIPTOR.message_types_by_name['TransformGradientArchive'] = _TRANSFORMGRADIENTARCHIVE
DESCRIPTOR.message_types_by_name['GradientArchive'] = _GRADIENTARCHIVE
DESCRIPTOR.message_types_by_name['ImageFillArchive'] = _IMAGEFILLARCHIVE
DESCRIPTOR.message_types_by_name['FillArchive'] = _FILLARCHIVE
DESCRIPTOR.message_types_by_name['StrokePatternArchive'] = _STROKEPATTERNARCHIVE
DESCRIPTOR.message_types_by_name['StrokeArchive'] = _STROKEARCHIVE
DESCRIPTOR.message_types_by_name['SmartStrokeArchive'] = _SMARTSTROKEARCHIVE
DESCRIPTOR.message_types_by_name['FrameArchive'] = _FRAMEARCHIVE
DESCRIPTOR.message_types_by_name['PatternedStrokeArchive'] = _PATTERNEDSTROKEARCHIVE
DESCRIPTOR.message_types_by_name['LineEndArchive'] = _LINEENDARCHIVE
DESCRIPTOR.message_types_by_name['ShadowArchive'] = _SHADOWARCHIVE
DESCRIPTOR.message_types_by_name['DropShadowArchive'] = _DROPSHADOWARCHIVE
DESCRIPTOR.message_types_by_name['ContactShadowArchive'] = _CONTACTSHADOWARCHIVE
DESCRIPTOR.message_types_by_name['CurvedShadowArchive'] = _CURVEDSHADOWARCHIVE
DESCRIPTOR.message_types_by_name['ReflectionArchive'] = _REFLECTIONARCHIVE
DESCRIPTOR.message_types_by_name['ImageAdjustmentsArchive'] = _IMAGEADJUSTMENTSARCHIVE
DESCRIPTOR.message_types_by_name['ShapeStylePropertiesArchive'] = _SHAPESTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['ShapeStyleArchive'] = _SHAPESTYLEARCHIVE
DESCRIPTOR.message_types_by_name['MediaStylePropertiesArchive'] = _MEDIASTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['MediaStyleArchive'] = _MEDIASTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ThemePresetsArchive'] = _THEMEPRESETSARCHIVE
DESCRIPTOR.message_types_by_name['ThemeReplaceFillPresetCommandArchive'] = _THEMEREPLACEFILLPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawableArchive'] = _DRAWABLEARCHIVE
DESCRIPTOR.message_types_by_name['ContainerArchive'] = _CONTAINERARCHIVE
DESCRIPTOR.message_types_by_name['GroupArchive'] = _GROUPARCHIVE
DESCRIPTOR.message_types_by_name['FreehandDrawingAnimationArchive'] = _FREEHANDDRAWINGANIMATIONARCHIVE
DESCRIPTOR.message_types_by_name['FreehandDrawingArchive'] = _FREEHANDDRAWINGARCHIVE
DESCRIPTOR.message_types_by_name['ShapeArchive'] = _SHAPEARCHIVE
DESCRIPTOR.message_types_by_name['ConnectionLineArchive'] = _CONNECTIONLINEARCHIVE
DESCRIPTOR.message_types_by_name['ImageArchive'] = _IMAGEARCHIVE
DESCRIPTOR.message_types_by_name['MaskArchive'] = _MASKARCHIVE
DESCRIPTOR.message_types_by_name['ImageDataAttributes'] = _IMAGEDATAATTRIBUTES
DESCRIPTOR.message_types_by_name['MovieArchive'] = _MOVIEARCHIVE
DESCRIPTOR.message_types_by_name['ExteriorTextWrapArchive'] = _EXTERIORTEXTWRAPARCHIVE
DESCRIPTOR.message_types_by_name['DrawableContentDescription'] = _DRAWABLECONTENTDESCRIPTION
DESCRIPTOR.message_types_by_name['FreehandDrawingContentDescription'] = _FREEHANDDRAWINGCONTENTDESCRIPTION
DESCRIPTOR.message_types_by_name['FreehandDrawingToolkitUIState'] = _FREEHANDDRAWINGTOOLKITUISTATE
DESCRIPTOR.message_types_by_name['StandinCaptionArchive'] = _STANDINCAPTIONARCHIVE
DESCRIPTOR.message_types_by_name['GuideArchive'] = _GUIDEARCHIVE
DESCRIPTOR.message_types_by_name['UserDefinedGuideArchive'] = _USERDEFINEDGUIDEARCHIVE
DESCRIPTOR.message_types_by_name['GuideStorageArchive'] = _GUIDESTORAGEARCHIVE
DESCRIPTOR.message_types_by_name['CanvasSelectionArchive'] = _CANVASSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['DrawableSelectionArchive'] = _DRAWABLESELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['GroupSelectionArchive'] = _GROUPSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['PathSelectionArchive'] = _PATHSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['InfoHyperlinkSelectionArchive'] = _INFOHYPERLINKSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['CommentStorageArchive'] = _COMMENTSTORAGEARCHIVE
DESCRIPTOR.message_types_by_name['ReplaceAnnotationAuthorCommandArchive'] = _REPLACEANNOTATIONAUTHORCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['PencilAnnotationArchive'] = _PENCILANNOTATIONARCHIVE
DESCRIPTOR.message_types_by_name['PencilAnnotationSelectionArchive'] = _PENCILANNOTATIONSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['PencilAnnotationStorageArchive'] = _PENCILANNOTATIONSTORAGEARCHIVE
DESCRIPTOR.message_types_by_name['SpecColorFillSetColorArchive'] = _SPECCOLORFILLSETCOLORARCHIVE
DESCRIPTOR.message_types_by_name['SpecFrameSetAssetScaleArchive'] = _SPECFRAMESETASSETSCALEARCHIVE
DESCRIPTOR.message_types_by_name['SpecGradientFillSetAngleArchive'] = _SPECGRADIENTFILLSETANGLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecImageFillSetTechniqueArchive'] = _SPECIMAGEFILLSETTECHNIQUEARCHIVE
DESCRIPTOR.message_types_by_name['SpecReflectionSetOpacityArchive'] = _SPECREFLECTIONSETOPACITYARCHIVE
DESCRIPTOR.message_types_by_name['SpecShadowSetAngleArchive'] = _SPECSHADOWSETANGLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecShadowSetColorArchive'] = _SPECSHADOWSETCOLORARCHIVE
DESCRIPTOR.message_types_by_name['SpecShadowSetOffsetArchive'] = _SPECSHADOWSETOFFSETARCHIVE
DESCRIPTOR.message_types_by_name['SpecShadowSetOpacityArchive'] = _SPECSHADOWSETOPACITYARCHIVE
DESCRIPTOR.message_types_by_name['SpecShadowSetRadiusArchive'] = _SPECSHADOWSETRADIUSARCHIVE
DESCRIPTOR.message_types_by_name['SpecStrokeSetColorArchive'] = _SPECSTROKESETCOLORARCHIVE
DESCRIPTOR.message_types_by_name['SpecStrokeSetPatternArchive'] = _SPECSTROKESETPATTERNARCHIVE
DESCRIPTOR.message_types_by_name['SpecStrokeSetWidthArchive'] = _SPECSTROKESETWIDTHARCHIVE
DESCRIPTOR.message_types_by_name['Attribution'] = _ATTRIBUTION
DESCRIPTOR.message_types_by_name['MovieFingerprint'] = _MOVIEFINGERPRINT
DESCRIPTOR.message_types_by_name['MovieFingerprintTrack'] = _MOVIEFINGERPRINTTRACK
DESCRIPTOR.enum_types_by_name['LineJoin'] = _LINEJOIN
DESCRIPTOR.extensions_by_name['fill'] = fill
DESCRIPTOR.extensions_by_name['stroke'] = stroke
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EdgeInsetsArchive = _reflection.GeneratedProtocolMessageType('EdgeInsetsArchive', (_message.Message,), dict(
  DESCRIPTOR = _EDGEINSETSARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.EdgeInsetsArchive)
  ))
_sym_db.RegisterMessage(EdgeInsetsArchive)

GeometryArchive = _reflection.GeneratedProtocolMessageType('GeometryArchive', (_message.Message,), dict(
  DESCRIPTOR = _GEOMETRYARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GeometryArchive)
  ))
_sym_db.RegisterMessage(GeometryArchive)

PointPathSourceArchive = _reflection.GeneratedProtocolMessageType('PointPathSourceArchive', (_message.Message,), dict(
  DESCRIPTOR = _POINTPATHSOURCEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PointPathSourceArchive)
  ))
_sym_db.RegisterMessage(PointPathSourceArchive)

ScalarPathSourceArchive = _reflection.GeneratedProtocolMessageType('ScalarPathSourceArchive', (_message.Message,), dict(
  DESCRIPTOR = _SCALARPATHSOURCEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ScalarPathSourceArchive)
  ))
_sym_db.RegisterMessage(ScalarPathSourceArchive)

BezierPathSourceArchive = _reflection.GeneratedProtocolMessageType('BezierPathSourceArchive', (_message.Message,), dict(
  DESCRIPTOR = _BEZIERPATHSOURCEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.BezierPathSourceArchive)
  ))
_sym_db.RegisterMessage(BezierPathSourceArchive)

CalloutPathSourceArchive = _reflection.GeneratedProtocolMessageType('CalloutPathSourceArchive', (_message.Message,), dict(
  DESCRIPTOR = _CALLOUTPATHSOURCEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.CalloutPathSourceArchive)
  ))
_sym_db.RegisterMessage(CalloutPathSourceArchive)

ConnectionLinePathSourceArchive = _reflection.GeneratedProtocolMessageType('ConnectionLinePathSourceArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONLINEPATHSOURCEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ConnectionLinePathSourceArchive)
  ))
_sym_db.RegisterMessage(ConnectionLinePathSourceArchive)

EditableBezierPathSourceArchive = _reflection.GeneratedProtocolMessageType('EditableBezierPathSourceArchive', (_message.Message,), dict(

  Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
    DESCRIPTOR = _EDITABLEBEZIERPATHSOURCEARCHIVE_NODE,
    __module__ = 'TSDArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSD.EditableBezierPathSourceArchive.Node)
    ))
  ,

  Subpath = _reflection.GeneratedProtocolMessageType('Subpath', (_message.Message,), dict(
    DESCRIPTOR = _EDITABLEBEZIERPATHSOURCEARCHIVE_SUBPATH,
    __module__ = 'TSDArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSD.EditableBezierPathSourceArchive.Subpath)
    ))
  ,
  DESCRIPTOR = _EDITABLEBEZIERPATHSOURCEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.EditableBezierPathSourceArchive)
  ))
_sym_db.RegisterMessage(EditableBezierPathSourceArchive)
_sym_db.RegisterMessage(EditableBezierPathSourceArchive.Node)
_sym_db.RegisterMessage(EditableBezierPathSourceArchive.Subpath)

PathSourceArchive = _reflection.GeneratedProtocolMessageType('PathSourceArchive', (_message.Message,), dict(
  DESCRIPTOR = _PATHSOURCEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PathSourceArchive)
  ))
_sym_db.RegisterMessage(PathSourceArchive)

AngleGradientArchive = _reflection.GeneratedProtocolMessageType('AngleGradientArchive', (_message.Message,), dict(
  DESCRIPTOR = _ANGLEGRADIENTARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.AngleGradientArchive)
  ))
_sym_db.RegisterMessage(AngleGradientArchive)

TransformGradientArchive = _reflection.GeneratedProtocolMessageType('TransformGradientArchive', (_message.Message,), dict(
  DESCRIPTOR = _TRANSFORMGRADIENTARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.TransformGradientArchive)
  ))
_sym_db.RegisterMessage(TransformGradientArchive)

GradientArchive = _reflection.GeneratedProtocolMessageType('GradientArchive', (_message.Message,), dict(

  GradientStop = _reflection.GeneratedProtocolMessageType('GradientStop', (_message.Message,), dict(
    DESCRIPTOR = _GRADIENTARCHIVE_GRADIENTSTOP,
    __module__ = 'TSDArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSD.GradientArchive.GradientStop)
    ))
  ,
  DESCRIPTOR = _GRADIENTARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GradientArchive)
  ))
_sym_db.RegisterMessage(GradientArchive)
_sym_db.RegisterMessage(GradientArchive.GradientStop)

ImageFillArchive = _reflection.GeneratedProtocolMessageType('ImageFillArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEFILLARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageFillArchive)
  ))
_sym_db.RegisterMessage(ImageFillArchive)

FillArchive = _reflection.GeneratedProtocolMessageType('FillArchive', (_message.Message,), dict(
  DESCRIPTOR = _FILLARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.FillArchive)
  ))
_sym_db.RegisterMessage(FillArchive)

StrokePatternArchive = _reflection.GeneratedProtocolMessageType('StrokePatternArchive', (_message.Message,), dict(
  DESCRIPTOR = _STROKEPATTERNARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.StrokePatternArchive)
  ))
_sym_db.RegisterMessage(StrokePatternArchive)

StrokeArchive = _reflection.GeneratedProtocolMessageType('StrokeArchive', (_message.Message,), dict(
  DESCRIPTOR = _STROKEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.StrokeArchive)
  ))
_sym_db.RegisterMessage(StrokeArchive)

SmartStrokeArchive = _reflection.GeneratedProtocolMessageType('SmartStrokeArchive', (_message.Message,), dict(
  DESCRIPTOR = _SMARTSTROKEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SmartStrokeArchive)
  ))
_sym_db.RegisterMessage(SmartStrokeArchive)

FrameArchive = _reflection.GeneratedProtocolMessageType('FrameArchive', (_message.Message,), dict(
  DESCRIPTOR = _FRAMEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.FrameArchive)
  ))
_sym_db.RegisterMessage(FrameArchive)

PatternedStrokeArchive = _reflection.GeneratedProtocolMessageType('PatternedStrokeArchive', (_message.Message,), dict(
  DESCRIPTOR = _PATTERNEDSTROKEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PatternedStrokeArchive)
  ))
_sym_db.RegisterMessage(PatternedStrokeArchive)

LineEndArchive = _reflection.GeneratedProtocolMessageType('LineEndArchive', (_message.Message,), dict(
  DESCRIPTOR = _LINEENDARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.LineEndArchive)
  ))
_sym_db.RegisterMessage(LineEndArchive)

ShadowArchive = _reflection.GeneratedProtocolMessageType('ShadowArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHADOWARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ShadowArchive)
  ))
_sym_db.RegisterMessage(ShadowArchive)

DropShadowArchive = _reflection.GeneratedProtocolMessageType('DropShadowArchive', (_message.Message,), dict(
  DESCRIPTOR = _DROPSHADOWARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DropShadowArchive)
  ))
_sym_db.RegisterMessage(DropShadowArchive)

ContactShadowArchive = _reflection.GeneratedProtocolMessageType('ContactShadowArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONTACTSHADOWARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ContactShadowArchive)
  ))
_sym_db.RegisterMessage(ContactShadowArchive)

CurvedShadowArchive = _reflection.GeneratedProtocolMessageType('CurvedShadowArchive', (_message.Message,), dict(
  DESCRIPTOR = _CURVEDSHADOWARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.CurvedShadowArchive)
  ))
_sym_db.RegisterMessage(CurvedShadowArchive)

ReflectionArchive = _reflection.GeneratedProtocolMessageType('ReflectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFLECTIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ReflectionArchive)
  ))
_sym_db.RegisterMessage(ReflectionArchive)

ImageAdjustmentsArchive = _reflection.GeneratedProtocolMessageType('ImageAdjustmentsArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEADJUSTMENTSARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageAdjustmentsArchive)
  ))
_sym_db.RegisterMessage(ImageAdjustmentsArchive)

ShapeStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('ShapeStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPESTYLEPROPERTIESARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ShapeStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(ShapeStylePropertiesArchive)

ShapeStyleArchive = _reflection.GeneratedProtocolMessageType('ShapeStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPESTYLEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ShapeStyleArchive)
  ))
_sym_db.RegisterMessage(ShapeStyleArchive)

MediaStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('MediaStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _MEDIASTYLEPROPERTIESARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MediaStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(MediaStylePropertiesArchive)

MediaStyleArchive = _reflection.GeneratedProtocolMessageType('MediaStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _MEDIASTYLEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MediaStyleArchive)
  ))
_sym_db.RegisterMessage(MediaStyleArchive)

ThemePresetsArchive = _reflection.GeneratedProtocolMessageType('ThemePresetsArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEPRESETSARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ThemePresetsArchive)
  ))
_sym_db.RegisterMessage(ThemePresetsArchive)

ThemeReplaceFillPresetCommandArchive = _reflection.GeneratedProtocolMessageType('ThemeReplaceFillPresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEREPLACEFILLPRESETCOMMANDARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ThemeReplaceFillPresetCommandArchive)
  ))
_sym_db.RegisterMessage(ThemeReplaceFillPresetCommandArchive)

DrawableArchive = _reflection.GeneratedProtocolMessageType('DrawableArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableArchive)
  ))
_sym_db.RegisterMessage(DrawableArchive)

ContainerArchive = _reflection.GeneratedProtocolMessageType('ContainerArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ContainerArchive)
  ))
_sym_db.RegisterMessage(ContainerArchive)

GroupArchive = _reflection.GeneratedProtocolMessageType('GroupArchive', (_message.Message,), dict(
  DESCRIPTOR = _GROUPARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GroupArchive)
  ))
_sym_db.RegisterMessage(GroupArchive)

FreehandDrawingAnimationArchive = _reflection.GeneratedProtocolMessageType('FreehandDrawingAnimationArchive', (_message.Message,), dict(
  DESCRIPTOR = _FREEHANDDRAWINGANIMATIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.FreehandDrawingAnimationArchive)
  ))
_sym_db.RegisterMessage(FreehandDrawingAnimationArchive)

FreehandDrawingArchive = _reflection.GeneratedProtocolMessageType('FreehandDrawingArchive', (_message.Message,), dict(
  DESCRIPTOR = _FREEHANDDRAWINGARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.FreehandDrawingArchive)
  ))
_sym_db.RegisterMessage(FreehandDrawingArchive)

ShapeArchive = _reflection.GeneratedProtocolMessageType('ShapeArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ShapeArchive)
  ))
_sym_db.RegisterMessage(ShapeArchive)

ConnectionLineArchive = _reflection.GeneratedProtocolMessageType('ConnectionLineArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONLINEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ConnectionLineArchive)
  ))
_sym_db.RegisterMessage(ConnectionLineArchive)

ImageArchive = _reflection.GeneratedProtocolMessageType('ImageArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageArchive)
  ))
_sym_db.RegisterMessage(ImageArchive)

MaskArchive = _reflection.GeneratedProtocolMessageType('MaskArchive', (_message.Message,), dict(
  DESCRIPTOR = _MASKARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MaskArchive)
  ))
_sym_db.RegisterMessage(MaskArchive)

ImageDataAttributes = _reflection.GeneratedProtocolMessageType('ImageDataAttributes', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEDATAATTRIBUTES,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageDataAttributes)
  ))
_sym_db.RegisterMessage(ImageDataAttributes)

MovieArchive = _reflection.GeneratedProtocolMessageType('MovieArchive', (_message.Message,), dict(
  DESCRIPTOR = _MOVIEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MovieArchive)
  ))
_sym_db.RegisterMessage(MovieArchive)

ExteriorTextWrapArchive = _reflection.GeneratedProtocolMessageType('ExteriorTextWrapArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXTERIORTEXTWRAPARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ExteriorTextWrapArchive)
  ))
_sym_db.RegisterMessage(ExteriorTextWrapArchive)

DrawableContentDescription = _reflection.GeneratedProtocolMessageType('DrawableContentDescription', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLECONTENTDESCRIPTION,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableContentDescription)
  ))
_sym_db.RegisterMessage(DrawableContentDescription)

FreehandDrawingContentDescription = _reflection.GeneratedProtocolMessageType('FreehandDrawingContentDescription', (_message.Message,), dict(
  DESCRIPTOR = _FREEHANDDRAWINGCONTENTDESCRIPTION,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.FreehandDrawingContentDescription)
  ))
_sym_db.RegisterMessage(FreehandDrawingContentDescription)

FreehandDrawingToolkitUIState = _reflection.GeneratedProtocolMessageType('FreehandDrawingToolkitUIState', (_message.Message,), dict(
  DESCRIPTOR = _FREEHANDDRAWINGTOOLKITUISTATE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.FreehandDrawingToolkitUIState)
  ))
_sym_db.RegisterMessage(FreehandDrawingToolkitUIState)

StandinCaptionArchive = _reflection.GeneratedProtocolMessageType('StandinCaptionArchive', (_message.Message,), dict(
  DESCRIPTOR = _STANDINCAPTIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.StandinCaptionArchive)
  ))
_sym_db.RegisterMessage(StandinCaptionArchive)

GuideArchive = _reflection.GeneratedProtocolMessageType('GuideArchive', (_message.Message,), dict(
  DESCRIPTOR = _GUIDEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GuideArchive)
  ))
_sym_db.RegisterMessage(GuideArchive)

UserDefinedGuideArchive = _reflection.GeneratedProtocolMessageType('UserDefinedGuideArchive', (_message.Message,), dict(
  DESCRIPTOR = _USERDEFINEDGUIDEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.UserDefinedGuideArchive)
  ))
_sym_db.RegisterMessage(UserDefinedGuideArchive)

GuideStorageArchive = _reflection.GeneratedProtocolMessageType('GuideStorageArchive', (_message.Message,), dict(
  DESCRIPTOR = _GUIDESTORAGEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GuideStorageArchive)
  ))
_sym_db.RegisterMessage(GuideStorageArchive)

CanvasSelectionArchive = _reflection.GeneratedProtocolMessageType('CanvasSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _CANVASSELECTIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.CanvasSelectionArchive)
  ))
_sym_db.RegisterMessage(CanvasSelectionArchive)

DrawableSelectionArchive = _reflection.GeneratedProtocolMessageType('DrawableSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLESELECTIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableSelectionArchive)
  ))
_sym_db.RegisterMessage(DrawableSelectionArchive)

GroupSelectionArchive = _reflection.GeneratedProtocolMessageType('GroupSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _GROUPSELECTIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GroupSelectionArchive)
  ))
_sym_db.RegisterMessage(GroupSelectionArchive)

PathSelectionArchive = _reflection.GeneratedProtocolMessageType('PathSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _PATHSELECTIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PathSelectionArchive)
  ))
_sym_db.RegisterMessage(PathSelectionArchive)

InfoHyperlinkSelectionArchive = _reflection.GeneratedProtocolMessageType('InfoHyperlinkSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _INFOHYPERLINKSELECTIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.InfoHyperlinkSelectionArchive)
  ))
_sym_db.RegisterMessage(InfoHyperlinkSelectionArchive)

CommentStorageArchive = _reflection.GeneratedProtocolMessageType('CommentStorageArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMENTSTORAGEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.CommentStorageArchive)
  ))
_sym_db.RegisterMessage(CommentStorageArchive)

ReplaceAnnotationAuthorCommandArchive = _reflection.GeneratedProtocolMessageType('ReplaceAnnotationAuthorCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _REPLACEANNOTATIONAUTHORCOMMANDARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ReplaceAnnotationAuthorCommandArchive)
  ))
_sym_db.RegisterMessage(ReplaceAnnotationAuthorCommandArchive)

PencilAnnotationArchive = _reflection.GeneratedProtocolMessageType('PencilAnnotationArchive', (_message.Message,), dict(
  DESCRIPTOR = _PENCILANNOTATIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PencilAnnotationArchive)
  ))
_sym_db.RegisterMessage(PencilAnnotationArchive)

PencilAnnotationSelectionArchive = _reflection.GeneratedProtocolMessageType('PencilAnnotationSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _PENCILANNOTATIONSELECTIONARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PencilAnnotationSelectionArchive)
  ))
_sym_db.RegisterMessage(PencilAnnotationSelectionArchive)

PencilAnnotationStorageArchive = _reflection.GeneratedProtocolMessageType('PencilAnnotationStorageArchive', (_message.Message,), dict(
  DESCRIPTOR = _PENCILANNOTATIONSTORAGEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PencilAnnotationStorageArchive)
  ))
_sym_db.RegisterMessage(PencilAnnotationStorageArchive)

SpecColorFillSetColorArchive = _reflection.GeneratedProtocolMessageType('SpecColorFillSetColorArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECCOLORFILLSETCOLORARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecColorFillSetColorArchive)
  ))
_sym_db.RegisterMessage(SpecColorFillSetColorArchive)

SpecFrameSetAssetScaleArchive = _reflection.GeneratedProtocolMessageType('SpecFrameSetAssetScaleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECFRAMESETASSETSCALEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecFrameSetAssetScaleArchive)
  ))
_sym_db.RegisterMessage(SpecFrameSetAssetScaleArchive)

SpecGradientFillSetAngleArchive = _reflection.GeneratedProtocolMessageType('SpecGradientFillSetAngleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECGRADIENTFILLSETANGLEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecGradientFillSetAngleArchive)
  ))
_sym_db.RegisterMessage(SpecGradientFillSetAngleArchive)

SpecImageFillSetTechniqueArchive = _reflection.GeneratedProtocolMessageType('SpecImageFillSetTechniqueArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECIMAGEFILLSETTECHNIQUEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecImageFillSetTechniqueArchive)
  ))
_sym_db.RegisterMessage(SpecImageFillSetTechniqueArchive)

SpecReflectionSetOpacityArchive = _reflection.GeneratedProtocolMessageType('SpecReflectionSetOpacityArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECREFLECTIONSETOPACITYARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecReflectionSetOpacityArchive)
  ))
_sym_db.RegisterMessage(SpecReflectionSetOpacityArchive)

SpecShadowSetAngleArchive = _reflection.GeneratedProtocolMessageType('SpecShadowSetAngleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSHADOWSETANGLEARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecShadowSetAngleArchive)
  ))
_sym_db.RegisterMessage(SpecShadowSetAngleArchive)

SpecShadowSetColorArchive = _reflection.GeneratedProtocolMessageType('SpecShadowSetColorArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSHADOWSETCOLORARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecShadowSetColorArchive)
  ))
_sym_db.RegisterMessage(SpecShadowSetColorArchive)

SpecShadowSetOffsetArchive = _reflection.GeneratedProtocolMessageType('SpecShadowSetOffsetArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSHADOWSETOFFSETARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecShadowSetOffsetArchive)
  ))
_sym_db.RegisterMessage(SpecShadowSetOffsetArchive)

SpecShadowSetOpacityArchive = _reflection.GeneratedProtocolMessageType('SpecShadowSetOpacityArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSHADOWSETOPACITYARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecShadowSetOpacityArchive)
  ))
_sym_db.RegisterMessage(SpecShadowSetOpacityArchive)

SpecShadowSetRadiusArchive = _reflection.GeneratedProtocolMessageType('SpecShadowSetRadiusArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSHADOWSETRADIUSARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecShadowSetRadiusArchive)
  ))
_sym_db.RegisterMessage(SpecShadowSetRadiusArchive)

SpecStrokeSetColorArchive = _reflection.GeneratedProtocolMessageType('SpecStrokeSetColorArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSTROKESETCOLORARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecStrokeSetColorArchive)
  ))
_sym_db.RegisterMessage(SpecStrokeSetColorArchive)

SpecStrokeSetPatternArchive = _reflection.GeneratedProtocolMessageType('SpecStrokeSetPatternArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSTROKESETPATTERNARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecStrokeSetPatternArchive)
  ))
_sym_db.RegisterMessage(SpecStrokeSetPatternArchive)

SpecStrokeSetWidthArchive = _reflection.GeneratedProtocolMessageType('SpecStrokeSetWidthArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSTROKESETWIDTHARCHIVE,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SpecStrokeSetWidthArchive)
  ))
_sym_db.RegisterMessage(SpecStrokeSetWidthArchive)

Attribution = _reflection.GeneratedProtocolMessageType('Attribution', (_message.Message,), dict(
  DESCRIPTOR = _ATTRIBUTION,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.Attribution)
  ))
_sym_db.RegisterMessage(Attribution)

MovieFingerprint = _reflection.GeneratedProtocolMessageType('MovieFingerprint', (_message.Message,), dict(
  DESCRIPTOR = _MOVIEFINGERPRINT,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MovieFingerprint)
  ))
_sym_db.RegisterMessage(MovieFingerprint)

MovieFingerprintTrack = _reflection.GeneratedProtocolMessageType('MovieFingerprintTrack', (_message.Message,), dict(
  DESCRIPTOR = _MOVIEFINGERPRINTTRACK,
  __module__ = 'TSDArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MovieFingerprintTrack)
  ))
_sym_db.RegisterMessage(MovieFingerprintTrack)

fill.message_type = _FILLARCHIVE
TSSArchives__pb2.CommandPropertyEntryArchive.RegisterExtension(fill)
stroke.message_type = _STROKEARCHIVE
TSSArchives__pb2.CommandPropertyEntryArchive.RegisterExtension(stroke)
_THEMEPRESETSARCHIVE.extensions_by_name['extension'].message_type = _THEMEPRESETSARCHIVE
TSSArchives__pb2.ThemeArchive.RegisterExtension(_THEMEPRESETSARCHIVE.extensions_by_name['extension'])
_FREEHANDDRAWINGARCHIVE.extensions_by_name['freehand_drawing_archive'].message_type = _FREEHANDDRAWINGARCHIVE
GroupArchive.RegisterExtension(_FREEHANDDRAWINGARCHIVE.extensions_by_name['freehand_drawing_archive'])
_IMAGEDATAATTRIBUTES.extensions_by_name['image_data_attributes'].message_type = _IMAGEDATAATTRIBUTES
TSPMessages__pb2.DataAttributes.RegisterExtension(_IMAGEDATAATTRIBUTES.extensions_by_name['image_data_attributes'])

_BEZIERPATHSOURCEARCHIVE.fields_by_name['path_string']._options = None
_IMAGEFILLARCHIVE.fields_by_name['originalimagedata']._options = None
_SHAPEARCHIVE.fields_by_name['head_line_end']._options = None
_SHAPEARCHIVE.fields_by_name['tail_line_end']._options = None
_MOVIEARCHIVE.fields_by_name['loopOptionAsInteger']._options = None
_MOVIEARCHIVE.fields_by_name['autoPlay']._options = None
_FREEHANDDRAWINGTOOLKITUISTATE.fields_by_name['current_color']._options = None
_CANVASSELECTIONARCHIVE.fields_by_name['container']._options = None
# @@protoc_insertion_point(module_scope)
